#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class AlbumsRelativealbum(Common):
    '''获取某个专辑的相关推荐专辑'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:albumId.
        albumId:要获得相关推荐的专辑id
        '''
        
        assert 'albumId' in param_dict.keys(), 'There is no albumId in the given params!'
        super(AlbumsRelativealbum, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/albums/relative_album'

class TracksRelativealbum(Common):
    '''获取某个声音的相关推荐专辑'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:trackId.
        trackId:要获得相关推荐的声音id
        '''
        
        assert 'trackId' in param_dict.keys(), 'There is no trackId in the given params!'
        super(TracksRelativealbum, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/tracks/relative_album'

class AlbumsRecommenddownload(Common):
    '''获取下载听模块的推荐下载专辑'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:calc_dimension; 可选:page,count.
        calc_dimension:计算维度,现支持经典(0),最火(1),最新(2),播放最多(3)
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'calc_dimension' in param_dict.keys(), 'There is no calc_dimension in the given params!'
        super(AlbumsRecommenddownload, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/albums/recommend_download'

class AlbumsGuesslike(Common):
    '''猜你喜欢的专辑.和在喜马拉雅主app的"猜你喜欢"栏点"更多"链接后返回的数据一样'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:device_type,device_id; 可选:like_count.
        device_type:1-IOS系统,2-Android系统,3-Web,4-Linux系统,5-ecos系统,6-qnix系统
        device_id:设备唯一标识,如果公共擦拭农户里已经有device_id,参数则不需要再传
        like_count:返回几条,不填则默认为3,取值区间为[1, 50]
        '''
        
        assert 'device_type' in param_dict.keys(), 'There is no device_type in the given params!'
        assert 'device_id' in param_dict.keys(), 'There is no device_id in the given params!'
        super(AlbumsGuesslike, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/albums/guess_like'

class AlbumsDiscoveryrecommendalbums(Common):
    '''获取运营人员在发现页配置的分类维度专辑推荐模块的列表样'''
    def __init__(self, param_dict):
        '''
        参数:公共参数; 可选:display_count.
        display_count:每个分类维度专辑推荐模块包含的专辑数,不填则默认为3,取值区间为[1, 20]
        '''
        
        super(AlbumsDiscoveryrecommendalbums, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/albums/discovery_recommend_albums'

class AlbumsCategoryrecommendalbums(Common):
    '''获取运营人员在发现页配置的分类维度专辑推荐模块的列表样'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:category_id; 可选:display_count.
        category_id:分类ID,指定分类
        display_count:每个分类维度专辑推荐模块包含的专辑数,不填则默认为3,取值区间为[1, 20]
        '''
        
        assert 'category_id' in param_dict.keys(), 'There is no category_id in the given params!'
        super(AlbumsCategoryrecommendalbums, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/albums/category_recommend_albums'


# s = {'device_type': '1', 'device_id': 'E4B3185B0932'}
# t = AlbumsGuesslike(s).get()
# print(t)
#'error_desc': 'access_token is invalid or expired'

# s = {'display_count':'3'}
# t = AlbumsDiscoveryrecommendalbums(s).get()
# print(t)

# s = {'category_id':'5621'}
# t = AlbumsCategoryrecommendalbums(s).get()
# print(t)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-27 上午9:13
# @Author  : Enoch.Xiang
# @Site    : shanghai
# @File    : playlist
# @Contact : xiangwenzhuo@yeah.net
"""

import API.column as api
import traceback
from utils import logger
import utils.decorator as decorator
import utils.exception as exception
import utils.result as result


LOG = logger.get_logger(__name__)
params_check = decorator.params_check


@params_check
def hotplaylists(params):
    '''获取精品听单列表'''
    LOG.info('hotplaylist service:')
    LOG.info('params is %s' % params)
    try:
        if 'count' in params.keys():
            count = params['count']
        else:
            count = 20
        if 'page' in params.keys():
            page = params['page']
        else:
            page = 1
        text = {'page': page, 'count': count}
        data = api.ColumnQualitylist(text).get()
        return result.PlayListResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())

@params_check
def detail(params):
    '''听单详情'''
    LOG.info('playlist detail service:')
    LOG.info('params is %s' % params)
    try:
        if 'playlistid' in params.keys():
            playlistid = params['playlistid']
        else:
            return result.ErrorResult(exception.NoPlayListIdError())
        text = {'id': playlistid}
        data = api.ColumnDetail(text).get()
        return result.PlayListResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())



#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/2/28 9:39
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : client
# @Project : roewe_voice 
# @Contact : guangze.yu@foxmail.com
"""
import pika
import config.rabbitmq as cfg
from utils import logger


LOG = logger.get_logger(__name__)
HOST = cfg.pika_host
PORT = cfg.pika_port
USER = cfg.pika_username
PWD = cfg.pika_password


class PikaClient(object):
    """Class PikaClient
    A client for rabbitMQ using tornado ioloop.
    """
    def __init__(self, io_loop):
        print('PikaClient: __init__')
        self.io_loop = io_loop
        self.connected = False
        self.connecting = False
        self.connection = None
        self.channel = None
        self.message_count = 0

    def connect(self):
        if self.connecting:
            return
        self.connecting = True
        cred = pika.PlainCredentials(USER, PWD)
        param = pika.ConnectionParameters(host=HOST,
                                          port=PORT,
                                          virtual_host='/',
                                          credentials=cred)
        self.connection = \
            pika.adapters.TornadoConnection(parameters=param,
                                            on_open_callback=self.on_connected,
                                            stop_ioloop_on_close=False)
        self.connection.add_on_close_callback(self.on_closed)

    def on_connected(self, connection):
        print('PikaClient: connected to RabbitMQ')
        self.connected = True
        self.connection = connection
        self.connection.channel(self.on_channel_open)

    def on_channel_open(self, channel):
        print('PikaClient: Channel %s open, Declaring exchange' % channel)
        self.channel = channel

    def on_closed(self):
        print('PikaClient: rabbit connection closed')
        self.io_loop.stop()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class SubscribeGetalbumsbyuid(Common):
    '''获取喜马拉雅用户的动态更新的订阅专辑列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:uid,updated_at; 可选:offset.
        uid:当前用户ID
        updated_at:Unix毫秒时间戳,表示获取updated_at更新时间点之前更新的offset条订阅专辑;
                  (为0表示从当前时间点最新更新的第一条订阅专辑开始获取)
        offset:拉取updated_at时间点之前更新的订阅专辑数目,默认20,最多不超过200
        '''
        
        assert 'uid' in param_dict.keys(), 'There is no uid in the given params!'
        assert 'updated_at' in param_dict.keys(), 'There is no updated_at in the given params!'
        super(SubscribeGetalbumsbyuid, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/subscribe/get_albums_by_uid'

class SubscribeAddordelete(Common):
    '''用户新增或取消已订阅专辑'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:uid,operation_type,album_id.
        uid:当前用户ID
        operation_type:操作类型,现支持删除(0),新增(1)
        album_id:需要更新的订阅专辑ID
        '''
        
        assert 'uid' in param_dict.keys(), 'There is no uid in the given params!'
        assert 'operation_type' in param_dict.keys(), 'There is no operation_type in the given params!'
        assert 'album_id' in param_dict.keys(), 'There is no album_id in the given params!'
        super(SubscribeAddordelete, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/subscribe/add_or_delete'

class SubscribeBatchadd(Common):
    '''用户批量新增已订阅专辑'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:uid,ids.
        uid:当前用户ID
        ids:需要更新的订阅专辑ID列表,用英文逗号分隔,例如1001,1002,1003
        '''
        
        assert 'uid' in param_dict.keys(), 'There is no uid in the given params!'
        assert 'ids' in param_dict.keys(), 'There is no ids in the given params!'
        super(SubscribeBatchadd, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/subscribe/batch_add'



#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/6/5 8:32
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : daliy_rec
# @Project : roewe_voice 
# @Contact : guangze.yu@foxmail.com
"""

import database.base_init as base_definition
import database.data_base as base_operation
import API.recommend as recommend
import API.ranks as ranks
import API.album as album


class RoeweRec(object):

    def __init__(self, vin, uid=None):
        """

        :param vin:
        :param uid:
        """
        self._vin = vin
        self._uid = uid
        self._conn = base_definition.Connect()
        self._history = base_operation.TracksHistoryList(vin, uid, self._conn).stat()
        self._track_his = self._history['track']
        self._album_his = self._history['album']
        self._artist_his = self._history['artist']
        self._conn.close()

    def get_recommend(self):
        album_byalbum = self._album_relative_by_playnums()
        album_bytrack = self._track_relative_by_playnums()
        album_byalbum.update(album_bytrack)
        return list(album_byalbum.values())

    def _album_relative_by_playnums(self, n=5):
        if len(self._album_his) == 0:
            params = {'device_type': 1, 'device_id': 'E4B3185B0932'}
            res = recommend.AlbumsGuesslike(params).get()
            out = {}
            temp = {str(j['id']): j for j in res}
            out.update(temp)
        else:
            album = self._album_his[:min(len(self._album_his), n)]
            out = {}
            for i in album:
                s = {'albumId': i['albumid']}
                res = recommend.AlbumsRelativealbum(s).get()
                temp = {str(j['id']): j for j in res['reletive_albums']}
                out.update(temp)
        return out

    def _track_relative_by_playnums(self, n=5):
        tracks = self._track_his[:min(len(self._album_his), n)]
        out = {}
        for i in tracks:
            s = {'trackId': i['track_id']}
            res = recommend.TracksRelativealbum(s).get()
            temp = {str(j['id']): j for j in res['reletive_albums']}
            out.update(temp)
        return out


class DailyRec(object):

    def __init__(self, vin=None, uid=None):
        """

        :param vin:
        :param uid:
        """
        self._vin = vin
        self._uid = uid

    def get_rank_id_list(self):
        s = {'rank_type': 1}
        res = ranks.RanksIndexlist(s).get()
        return list(set([j['id'] for i in res for j in i['index_rank_items']]))

    def get_recommend(self):
        ids = ''
        for i in self.get_rank_id_list():
            ids += str(i) + ','
        ids = {'ids': ids.strip(',')}
        res = album.GetBatch(ids).get()
        return res



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-7-05 上午10:13
# @Author  : Enoch.Xiang
# @Site    : shanghai
# @File    : playlist
# @Contact : xiangwenzhuo@yeah.net
"""

import API.demand as api
import traceback
from utils import logger
import utils.decorator as decorator
import utils.exception as exception
import utils.result as result


LOG = logger.get_logger(__name__)
params_check = decorator.params_check


@params_check
def metadatalbums(params):
    """

    :param params:
    :return:
    """
    LOG.info('album/metadatalbums service:')
    LOG.info('params is %s' % params)
    try:
        text = {}
        data = api.CategoriesList(text).get()
        return result.AlbumResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def V2TagsList(params):
    """

    :param params: a dict contain category_id, type
    :return:
    """
    LOG.info('album/V2TagsList service:')
    LOG.info('params is %s' % params)
    try:
        id = params['category_id']
        type = params['type']
        text = {'category_id': id, 'type': type}
        data = api.V2TagsList(text).get()
        return result.AlbumResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def V2AlbumsList(params):
    """
    根据分类和标签获取某个分类某个标签下的热门专辑列表/最新专辑列表/最多播放专辑列表(V2版本)
    :param params: a dict, contain access_token, category_id, optional param, contain calc_dimension, page and count
        参数:除公共参数外,必须包含:category_id,calc_dimension; 可选:tag_name,page,count.
        category_id:分类ID,指定分类,为0时表示热门分类
        calc_dimension:calc_dimension:计算维度,现支持最火(1),最新(2),经典或播放最多(3)
        tag_name:分类下对应的专辑标签
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
    :return:
    """
    LOG.info('album/V2AlbumList')
    LOG.info('params is %s' % params)
    try:
        id = params['category_id']
        calc = params['calc_dimension']
        text = {'category_id': id, 'calc_dimension': calc}
        data = api.V2AlbumsList(text).get()
        return result.AlbumResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def tags(params):
    """

    :param params:
    :return:
    """
    LOG.info('album/tags')
    LOG.info('params is %s' % params)
    try:
        key = int(params['key'])
        res1 = [[3], [12, 16], [9, 39], [4, 28, 23, 24],
                [6], [2, 29], [40, 34], [15],
                [1], [21], [30, 13, 32, 38, 41], [8, 18],
                [7], [17], [22], [31, 10]]
        num = res1[key]
        a = int(20 / len(num))
        data = []
        for i in num:
            text = {'category_id': i, 'calc_dimension': 1}
            res = api.V2AlbumsList(text).get()
            res2 = res['albums'][0:a]
            for n in res2:
                data.append(n)
        return result.AlbumResult(res=data)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError)




#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class OpenapicollectorappLivesinglerecord(Common):
    '''上传单条直播播放数据'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:radio_id,duration,played_secs; 可选:program_schedule_id,program_id,started_at,uid.
        radio_id:电台ID
        duration:播放时长,单位秒.即播放一个音频过程中,真正处于播放中状态的总时间.
        played_secs:播放第几秒或最后播放到的位置,是相对于这个音频开始位置的一个值.
                    如果没有拖动播放条、快进、快退、暂停、单曲循环等操作,played_secs的值一般和duration一致.
        program_schedule_id:节目排期ID
        program_id:节目ID
        started_at:播放开始时刻,Unix毫秒数时间戳
        uid:喜马拉雅用户ID
        '''
        
        assert 'radio_id' in param_dict.keys(), 'There is no radio_id in the given params!'
        assert 'duration' in param_dict.keys(), 'There is no duration in the given params!'
        assert 'played_secs' in param_dict.keys(), 'There is no played_secs in the given params!'
        super(OpenapicollectorappLivesinglerecord, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/openapi-collector-app/live_single_record'

class OpenapicollectorappLivebatchrecords(Common):
    '''批量上传直播播放数据,每次批量小于等于200条'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:live_records; 可选:uid.
        live_records:直播播放数据列表,每条播放数据包含下列字段
            radio_id:电台ID
            program_schedule_id:节目排期ID
            program_id:节目ID
            duration:播放时长,单位秒.即播放一个音频过程中,真正处于播放中状态的总时间.
            played_secs:播放第几秒或最后播放到的位置,是相对于这个音频开始位置的一个值.
                        如果没有拖动播放条、快进、快退、暂停、单曲循环等操作,played_secs的值一般和duration一致.
            started_at:播放开始时刻,Unix毫秒数时间戳
        uid:喜马拉雅用户ID
        '''
        
        assert 'live_records' in param_dict.keys(), 'There is no live_records in the given params!'
        super(OpenapicollectorappLivebatchrecords, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/openapi-collector-app/live_batch_records'

class OpenapicollectorappTracksinglerecord(Common):
    '''上传单条声音播放数据'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:track_id,duration,played_secs,play_type; 可选:started_at,uid.
        track_id:声音ID
        duration:播放时长,单位秒.即播放一个音频过程中,真正处于播放中状态的总时间.
        played_secs:播放第几秒或最后播放到的位置,是相对于这个音频开始位置的一个值.
                    如果没有拖动播放条、快进、快退、暂停、单曲循环等操作,played_secs的值一般和duration一致.
        play_type:0-联网播放,1-断网播放
        started_at:播放开始时刻,Unix毫秒数时间戳
        uid:喜马拉雅用户ID
        '''
        
        assert 'track_id' in param_dict.keys(), 'There is no track_id in the given params!'
        assert 'duration' in param_dict.keys(), 'There is no duration in the given params!'
        assert 'played_secs' in param_dict.keys(), 'There is no played_secs in the given params!'
        assert 'play_type' in param_dict.keys(), 'There is no play_type in the given params!'
        super(OpenapicollectorappTracksinglerecord, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/openapi-collector-app/track_single_record'

class OpenapicollectorappTrackbatchrecords(Common):
    '''批量上传声音播放数据,每次批量小于等于200条'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:track_records; 可选:uid.
        track_records:直播播放数据列表,每条播放数据包含下列字段
            track_id:声音ID
            duration:播放时长,单位秒.即播放一个音频过程中,真正处于播放中状态的总时间.
            played_secs:播放第几秒或最后播放到的位置,是相对于这个音频开始位置的一个值.
                        如果没有拖动播放条、快进、快退、暂停、单曲循环等操作,played_secs的值一般和duration一致.
            started_at:播放开始时刻,Unix毫秒数时间戳
            play_type:0-联网播放,1-断网播放
        uid:喜马拉雅用户ID
        '''
        
        assert 'track_records' in param_dict.keys(), 'There is no track_records in the given params!'
        super(OpenapicollectorappTrackbatchrecords, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/openapi-collector-app/track_batch_records'

class OpenapicollectorappUpdatealbumchannelplaycount(Common):
    '''更新专辑的渠道播放数'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:album_id.
        album_id:专辑ID
        '''
        
        assert 'album_id' in param_dict.keys(), 'There is no album_id in the given params!'
        super(OpenapicollectorappUpdatealbumchannelplaycount, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/openapi-collector-app/update_album_channel_playcount'

class OpenapicollectorappUpdatealbumcolumnchannelplaycount(Common):
    '''更新专辑听单的渠道播放数'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:album_column_id.
        album_column_id:专辑听单的ID
        '''
        
        assert 'album_column_id' in param_dict.keys(), 'There is no album_column_id in the given params!'
        super(OpenapicollectorappUpdatealbumcolumnchannelplaycount, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/openapi-collector-app/update_album_cloumn_channel_playcount'

class OpenapicollectorappUpdatetrackcolumnchannelplaycount(Common):
    '''更新声音听单的渠道播放数'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:track_column_id.
        track_column_id:专辑听单的ID
        '''
        
        assert 'track_column_id' in param_dict.keys(), 'There is no track_column_id in the given params!'
        super(OpenapicollectorappUpdatetrackcolumnchannelplaycount, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/openapi-collector-app/update_track_cloumn_channel_playcount'



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-26 下午2:32
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : test
# @Contact : guangze.yu@foxmail.com
"""

import time
import utils.logger as logger
import utils.result as result


LOG = logger.get_logger(__name__)


def sleepout(params):
    """

    :param params:
    :return:
    """
    print(params)
    LOG.info('Params:%s', params)
    time.sleep(1)
    return result.TestResult(res='Hello!')





#!/usr/bin/python3
# -*- coding: utf-8 -*-

# -------------------------------------------------
#   @File_Name： album.py
#   @Author：    Enoch.Xiang
#   @contact：   xiangwenzhuo@yeah.net
#   @date：      18-7-19 下午4:11
#   @version：   1.0
# -------------------------------------------------
#   @Description :
#
#
# -------------------------------------------------


def delpoi():
    """
    @api {post} /delpoi 删除收藏
    @apiVersion 0.1.0
    @apiGroup Collect
    @apiDescription 删除收藏

    @apiParam {Float} timestamp 时间戳
    @apiParam {String} location 经纬度

    @apiSuccess {String} data 成功标识

    @apiSuccessExample {json} Success-Response:
    {
        "data": "Success.",
        "req_id": "r_049b93db7754407bb872aaee3d28f352",
        "err_resp": {
            "code": "0",
            "msg": null
        }
    }

    @apiError 21020  No poi_id in the request params

    @apiErrorExample {json} Error-Response:
    {
        "err_resp": {
            "code": "21020",
            "msg": "No poi_id in the request params!"
        },
        "req_id": "r_da328a55dfbc46bda249122030b8677d"
    }
    """



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/5/3 上午11:01
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : zookeeper
# @File    : app_music
# @Contact : guangze.yu@foxmail.com
"""

# zookeeper config
zookeeper_host = '47.100.225.82:2181'



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class ColumnQualitylist(Common):
    '''获取精品听单列表'''
    def __init__(self, param_dict):
        '''
        参数:公共参数; 可选:page,count.
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        super(ColumnQualitylist, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/column/quality_list'

class ColumnDetail(Common):
    '''获取某个听单详情,每个听单包含听单简介信息和专辑或声音的列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:id.
        id:听单ID
        '''
        
        assert 'id' in param_dict.keys(), 'There is no id in the given params!'
        super(ColumnDetail, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/column/detail'


# t = {'id': '1977'}
# s = ColumnDetail(t).get()
# print(s)


#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 17-12-21 上午8:57
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : data_base
# @Contact : guangze.yu@foxmail.com
"""

import database.base_init as base
import datetime
import API.demand as demand_api
import API.column as column_api
import API.live as live_api
import API.announcers as ann
import traceback
import json

Connection = base.Connect()


def takeTime(elem):
    """
    function: 提取time字段
    :param elem:
    :return:
    """
    return elem['time']


class DateEncoder(json.JSONEncoder):
    def default(self, obj):
        if isinstance(obj, datetime.datetime):
            return obj.strftime('%Y-%m-%d %H:%M:%S')
        elif isinstance(obj, datetime.datetime):
            return obj.strftime("%Y-%m-%d")
        else:
            return json.JSONEncoder.default(self, obj)


class Common(object):
    def __init__(self, vin, uid=None, conn=Connection):
        self._vin = vin
        self._uid = uid
        self._conn = conn


class SearchWordHistory(Common):
    def __init__(self, vin, uid=None, conn=Connection):
        super(SearchWordHistory, self).__init__(vin, uid, conn)

    def get(self, start_time=None, end_time=None):
        starttime = start_time if start_time else datetime.datetime.now() - datetime.timedelta(720)
        endtime = end_time if end_time else datetime.datetime.now()
        try:
            if self._uid is None:
                query = ("SELECT "
                         "tb_searchword_history.keyword, "
                         "group_concat(tb_searchword_history.time "
                         "ORDER by tb_searchword_history.time DESC) "
                         "from tb_searchword_history "
                         "where tb_searchword_history.showinlist=1 "
                         "and tb_searchword_history.time "
                         "BETWEEN '%s'and'%s' "
                         "and tb_searchword_history.uid is NULL "
                         "AND tb_searchword_history.vin='%s' "
                         "group by tb_searchword_history.keyword "
                         "ORDER BY group_concat(tb_searchword_history.time "
                         "ORDER by tb_searchword_history.time DESC) DESC;"
                         % (starttime, endtime, self._vin))
            else:
                query = ("select "
                         "tb_searchword_history.keyword, "
                         "group_concat(tb_searchword_history.time "
                         "ORDER by tb_searchword_history.time DESC) "
                         "from tb_searchword_history "
                         "where tb_searchword_history.showinlist=1 "
                         "and tb_searchword_history.time "
                         "BETWEEN '%s'and'%s' "
                         "and tb_searchword_history.uid='%s' "
                         "group by tb_searchword_history.keyword "
                         "ORDER BY group_concat(tb_searchword_history.time "
                         "ORDER by tb_searchword_history.time DESC) DESC;"
                         % (starttime, endtime, self._uid))
            # log.info(query)
            data = self._conn.session.execute(query)
            out = [{'keyword': i[0]} for i in data]
            # log.info(out)
            self._conn.close()
            return out
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('get failre')
            return False

    def clear(self):
        try:
            query = self._conn.session.query(base.UserSearchKeyWordHistory)
            data = query.filter_by(vin=self._vin,
                                   uid=self._uid,
                                   showinlist=True).all()
            for i in data:
                i.showinlist = False
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('clear failre')
            return False

    def add(self, timestamp, keyword):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            data = {'uid': self._uid,
                    'vin': self._vin,
                    'time': time_array,
                    'keyword': keyword,
                    'showinlist': True}
            add_item = (base.UserSearchKeyWordHistory(**data))
            self._conn.session.add(add_item)
            self._conn.commit()
            self._conn.close()
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('add failre')
            return False


class TracksHistoryList(Common):
    def __init__(self, vin, uid=None, Conn=Connection):
        super(TracksHistoryList, self).__init__(vin, uid, Conn)

    def get(self, start_time=None, end_time=None):
        starttime = start_time if start_time else datetime.datetime.now()-datetime.timedelta(720)
        endtime = end_time if end_time else datetime.datetime.now()
        try:
            if self._uid is None:
                query = ("SELECT "
                         "tb_tracks_history.track_id, "
                         "tb_tracks_history.track_title,"
                         "tb_tracks_history.cover_url_small,"
                         "tb_tracks_history.cover_url_middle,"
                         "tb_tracks_history.cover_url_large,"
                         "tb_tracks_history.duration,"
                         "tb_tracks_history.play_url_32,"
                         "tb_tracks_history.play_url_64,"
                         "tb_tracks_history.valid,"
                         "group_concat(tb_tracks_history.time ORDER by tb_tracks_history.time DESC) "
                         "from tb_tracks_history LEFT JOIN tb_user_collect_track "
                         "on tb_tracks_history.track_id=tb_user_collect_track.track_id "
                         "where tb_tracks_history.time "
                         "BETWEEN '%s'and'%s' and tb_tracks_history.uid is NULL AND "
                         "tb_tracks_history.valid=TRUE  AND "
                         "tb_tracks_history.vin='%s' group by "
                         "tb_tracks_history.track_id ORDER BY "
                         "group_concat(tb_tracks_history.time "
                         "ORDER by tb_tracks_history.time DESC) DESC;"
                         % (starttime, endtime, self._vin))
            else:
                query = ("select "
                         "tb_tracks_history.track_id, "
                         "tb_tracks_history.track_title,"
                         "tb_tracks_history.cover_url_small,"
                         "tb_tracks_history.cover_url_middle,"
                         "tb_tracks_history.cover_url_large,"
                         "tb_tracks_history.duration,"
                         "tb_tracks_history.play_url_32,"
                         "tb_tracks_history.play_url_64,"
                         "tb_tracks_history.valid, "
                         "group_concat(tb_tracks_history.time ORDER by tb_tracks_history.time DESC) "
                         "from tb_tracks_history LEFT JOIN tb_user_collect_track "
                         "on tb_tracks_history.track_id=tb_user_collect_track.track_id "
                         "where tb_tracks_history.time "
                         "BETWEEN '%s'and'%s' and tb_tracks_history.uid='%s' AND "
                         "tb_tracks_history.valid=TRUE group by "
                         "tb_tracks_history.track_id order by "
                         "group_concat(tb_tracks_history.time ORDER by "
                         "tb_tracks_history.time DESC) DESC;"
                         % (starttime, endtime, self._uid))
            print(query)
            data = self._conn.session.execute(query)
            out = [{'track_id': i[0],
                    'track_title': i[1],
                    'cover_url_small': i[2],
                    'cover_url_middle': i[3],
                    'cover_url_large': i[4],
                    'duration': i[5],
                    'play_url_32': i[6],
                    'play_url_64': i[7],
                    'valid':i[8]} for i in data]
            self._conn.close()
            return out
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('get failre')
            return False

    def add(self, timestamp, track_id):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            s = {'ids': track_id}
            trackdata = demand_api.TracksGetbatch(s).get()['tracks'][0]
            track_title = trackdata['track_title']
            announcer_id = trackdata['announcer']['id']
            nickname = trackdata['announcer']['nickname']
            category_id = trackdata['category_id']
            album_id = trackdata['subordinated_album']['id']
            album_title = trackdata['subordinated_album']['album_title']
            play_count = trackdata['play_count']
            cover_url_small = trackdata['cover_url_small']
            cover_url_middle = trackdata['cover_url_middle']
            cover_url_large = trackdata['cover_url_large']
            duration = trackdata['duration']
            play_url_32 = trackdata['play_url_32']
            play_url_64 = trackdata['play_url_64']
            data = {'uid': self._uid,
                    'vin': self._vin,
                    'time': time_array,
                    'track_id': track_id,
                    'track_title': track_title,
                    'announcer_id': announcer_id,
                    'nickname': nickname,
                    'category_id': category_id,
                    'album_id': album_id,
                    'album_title': album_title,
                    'play_count': play_count,
                    'modifiedtime': time_array,
                    'cover_url_small': cover_url_small,
                    'cover_url_middle': cover_url_middle,
                    'cover_url_large': cover_url_large,
                    'play_url_32': play_url_32,
                    'play_url_64': play_url_64,
                    'duration': duration,
                    'valid': True}
            add_item = (base.UserTracksHistoryList(**data))
            self._conn.session.add(add_item)
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('add failre')
            return False

    def stat(self, n=50, start_time=None, end_time=None):
        starttime = start_time if start_time else datetime.datetime.now() - datetime.timedelta(720)
        endtime = end_time if end_time else datetime.datetime.now()
        try:
            if self._uid is None:
                query = ("SELECT "
                         "tb_tracks_history.track_id,"
                         "count(tb_tracks_history.track_id),"
                         "tb_tracks_history.track_title,"
                         "group_concat(time ORDER by time DESC) "
                         "from tb_tracks_history "
                         "where tb_tracks_history.time "
                         "BETWEEN '%s'and'%s' "
                         "and tb_tracks_history.uid is NULL "
                         "AND tb_tracks_history.vin='%s' "
                         "group by tb_tracks_history.track_id "
                         "ORDER BY count(track_id) DESC;"
                         % (starttime, endtime, self._vin))
            else:
                query = ("SELECT "
                         "tb_tracks_history.track_id,"
                         "count(tb_tracks_history.track_id),"
                         "tb_tracks_history.track_title,"
                         "group_concat(time ORDER by time DESC) "
                         "from tb_tracks_history "
                         "where tb_tracks_history.time "
                         "BETWEEN '%s'and'%s' "
                         "and tb_tracks_history.uid='%s' "
                         "group by tb_tracks_history.track_id "
                         "ORDER BY count(track_id) DESC;"
                         % (starttime, endtime, self._uid))

            track_data = self._conn.session.execute(query)
            if track_data:
                track_out = [{'track_id': i[0],
                              'playnum': i[1],
                              'track_title': i[2],
                              'playtime': i[3]} for i in track_data]
            else:
                track_out = None

            if self._uid is None:
                query = ("SELECT "
                         "tb_tracks_history.album_id,"
                         "count(tb_tracks_history.album_id),"
                         "group_concat(time ORDER by time DESC) "
                         "from tb_tracks_history "
                         "where tb_tracks_history.time "
                         "BETWEEN '%s'and'%s' "
                         "and tb_tracks_history.uid is NULL "
                         "AND tb_tracks_history.vin='%s' "
                         "group by tb_tracks_history.album_id "
                         "ORDER BY count(album_id) DESC;"
                         % (starttime, endtime, self._vin))
            else:
                query = ("SELECT "
                         "tb_tracks_history.album_id,"
                         "count(tb_tracks_history.album_id),"
                         "group_concat(time ORDER by time DESC) "
                         "from tb_tracks_history "
                         "where tb_tracks_history.time "
                         "BETWEEN '%s'and'%s' "
                         "and tb_tracks_history.uid='%s' "
                         "group by tb_tracks_history.album_id "
                         "ORDER BY count(album_id) DESC;"
                         % (starttime, endtime, self._uid))

            album_data = self._conn.session.execute(query)
            if album_data:
                album_out = [{'albumid': i[0],
                              'playnum': i[1],
                              'playtime': i[2]} for i in album_data]
            else:
                album_out = None

            if self._uid is None:
                query = ("SELECT "
                         "tb_tracks_history.announcer_id,"
                         "count(tb_tracks_history.announcer_id), "
                         "tb_tracks_history.nickname,"
                         "group_concat(time ORDER by time DESC) "
                         "from tb_tracks_history "
                         "where tb_tracks_history.time "
                         "BETWEEN '%s'and'%s' "
                         "and tb_tracks_history.uid is NULL "
                         "AND tb_tracks_history.vin='%s' "
                         "group by tb_tracks_history.announcer_id "
                         "ORDER BY count(announcer_id) DESC;"
                         % (starttime, endtime, self._vin))
            else:
                query = ("SELECT "
                         "tb_tracks_history.announcer_id,"
                         "count(tb_tracks_history.announcer_id), "
                         "tb_tracks_history.nickname,"
                         "group_concat(time ORDER by time DESC) "
                         "from tb_tracks_history "
                         "where tb_tracks_history.time "
                         "BETWEEN '%s'and'%s' "
                         "and tb_tracks_history.uid='%s' "
                         "group by tb_tracks_history.announcer_id "
                         "ORDER BY count(announcer_id) DESC;"
                         % (starttime, endtime, self._uid))

            artist_data = self._conn.session.execute(query)
            if artist_data:
                artist_out = [{'artistid': i[0],
                               'artistname': i[2],
                               'playnum': i[1],
                               'playtime': i[3]} for i in artist_data]
            else:
                artist_out = None
            out = {'track': track_out,
                   'album': album_out,
                   'artist': artist_out}
            self._conn.close()
            return out
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('cancel failre')
            return False

    def clear(self):
        """

        :return:
        """
        try:
            query = self._conn.session.query(base.UserTracksHistoryList)
            if self._uid is None:
                data = query.filter_by(vin=self._vin,
                                       uid=self._uid,
                                       valid=True).all()
                for i in data:
                    i.valid = False
            else:
                data = query.filter_by(uid=self._uid,
                                       valid=True).all()
                for i in data:
                    i.valid = False
            self._conn.commit()
            return True
        except:
            self._conn.session.rollback()
            traceback.print_exc()
            print('clear failre')
            return False


class CollectTrack(Common):
    def __init__(self, vin, uid=None, Conn=Connection):
        super(CollectTrack, self).__init__(vin, uid, Conn)

    def get(self):
        try:
            query = self._conn.session.query(base.UserCollectTrack)
            if self._uid is None:
                data = query.filter_by(vin=self._vin,
                                       uid=self._uid,
                                       favorite=True).all()
            else:
                data = query.filter_by(uid=self._uid, favorite=True).all()
            out = [{'track_id': i.track_id,
                    'track_title': i.track_title,
                    'duration': i.duration,
                    'cover_url_small': i.cover_url_small,
                    'cover_url_middle': i.cover_url_middle,
                    'cover_url_large': i.cover_url_large,
                    'play_url_32': i.play_url_32,
                    'play_url_64': i.play_url_64,
                    'time': i.time.strftime("%Y-%m-%d %H:%M:%S")} for i in data]
            out.sort(key=takeTime, reverse=True)
            out = out[0:500]
            self._conn.close()
            return out
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('cancel failre')
            return False

    def add(self, timestamp, track_id):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            if self._uid is None:
                collect = self._conn.session.query(base.UserCollectTrack).filter_by(uid=self._uid,
                                                                                    vin=self._vin,
                                                                                    track_id=track_id).first()
            else:
                collect = self._conn.session.query(base.UserCollectTrack).filter_by(uid=self._uid,
                                                                                    track_id=track_id).first()
            if collect is None:
                s = {'ids': track_id}
                trackdata = demand_api.TracksGetbatch(s).get()['tracks'][0]
                track_title = trackdata['track_title']
                duration = trackdata['duration']
                cover_url_small = trackdata['cover_url_small']
                cover_url_middle = trackdata['cover_url_middle']
                cover_url_large = trackdata['cover_url_large']
                play_url_32 = trackdata['play_url_32']
                play_url_64 = trackdata['play_url_64']
                data = {'uid': self._uid,
                        'vin': self._vin,
                        'track_id': track_id,
                        'duration': duration,
                        'cover_url_small': cover_url_small,
                        'cover_url_middle': cover_url_middle,
                        'cover_url_large': cover_url_large,
                        'play_url_32': play_url_32,
                        'play_url_64': play_url_64,
                        'track_title': track_title,
                        'favorite': True,
                        'time': time_array}
                add_item = base.UserCollectTrack(**data)
                self._conn.session.add(add_item)
            else:
                collect.favorite = True
                collect.vin = self._vin
                collect.time = time_array
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('add failre')
            return False

    def cancel(self, timestamp, track_id):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            if self._uid is None:
                collect = self._conn.session.query(base.UserCollectTrack).filter_by(uid=self._uid,
                                                                                    vin=self._vin,
                                                                                    track_id=track_id).first()
            else:
                collect = self._conn.session.query(base.UserCollectTrack).filter_by(uid=self._uid,
                                                                                    track_id=track_id).first()
            if collect is None:
                s = {'ids': track_id}
                trackdata = demand_api.TracksGetbatch(s).get()['tracks'][0]
                track_title = trackdata['track_title']
                duration = trackdata['duration']
                cover_url_small = trackdata['cover_url_small']
                cover_url_middle = trackdata['cover_url_middle']
                cover_url_large = trackdata['cover_url_large']
                play_url_32 = trackdata['play_url_32']
                play_url_64 = trackdata['play_url_64']
                data = {'uid': self._uid,
                        'vin': self._vin,
                        'track_id': track_id,
                        'duration': duration,
                        'cover_url_small': cover_url_small,
                        'cover_url_middle': cover_url_middle,
                        'cover_url_large': cover_url_large,
                        'play_url_32': play_url_32,
                        'play_url_64': play_url_64,
                        'track_title': track_title,
                        'favorite': False,
                        'time': time_array}
                add_item = (base.UserCollectTrack(**data))
                self._conn.session.add(add_item)
            else:
                collect.favorite = False
                collect.vin = self._vin
                collect.time = time_array
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('add failre')
            return False


class CollectPlayList(Common):
    def __init__(self, vin, uid=None, conn=Connection):
        super(CollectPlayList, self).__init__(vin, uid, conn)

    def get(self):
        try:
            query = self._conn.session.query(base.UserCollectPlayList)
            if self._uid is None:
                data = query.filter_by(vin=self._vin,
                                       uid=self._uid,
                                       favorite=True).all()
            else:
                data = query.filter_by(uid=self._uid, favorite=True).all()
            out = [{'playlistid': i.playlistid,
                    'playlistname': i.playlistname,
                    'imageS': i.imageSmall,
                    'imageM': i.imageMiddle,
                    'imageL': i.imageLarge} for i in data]
            self._conn.close()
            return out
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('get failre')
            return False

    def add(self, timestamp, playlistid, selflist=False):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            if self._uid is None:
                collect = self._conn.session.query(base.UserCollectPlayList)\
                    .filter_by(uid=self._uid,
                               vin=self._vin,
                               playlistid=playlistid,
                               selflist=selflist).first()
            else:
                collect = self._conn.session.query(base.UserCollectPlayList)\
                    .filter_by(uid=self._uid,
                               playlistid=playlistid,
                               selflist=selflist).first()
            if collect is None:
                if selflist:
                    if self._uid is None:
                        playlist = self._conn.session.query(base.UserPlayList)\
                            .filter_by(uid=self._uid,
                                       vin=self._vin,
                                       playlistid=playlistid).first()
                    else:
                        playlist = self._conn.session.query(base.UserPlayList) \
                            .filter_by(uid=self._uid,
                                       playlistid=playlistid).first()
                    if playlist is None:
                        return 'No %s in self playlist!' %playlistid
                    else:
                        imageS = playlist.imageSmall
                        imageL = playlist.imageLagre
                        playlistname = playlist.playlistname
                else:
                    s = {'id': playlistid}
                    playlist = column_api.ColumnDetail(s).get()
                    imageS = playlist['logo_small']
                    imageL = playlist['cover_url_large']
                    playlistname = playlist['column_editor']['nickname']
                data = {'uid': self._uid,
                        'vin': self._vin,
                        'playlistid': playlistid,
                        'playlistname': playlistname,
                        'imageSmall': imageS,
                        'imageLarge': imageL,
                        'favorite': True,
                        'time': time_array,
                        'selflist': selflist}
                add_item = (base.UserCollectPlayList(**data))
                self._conn.session.add(add_item)
            else:
                collect.favorite = True
                collect.vin = self._vin
                collect.time = time_array
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('add failre')
            return False

    def cancel(self, timestamp, playlistid, selflist=False):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            if self._uid is None:
                collect = self._conn.session.query(base.UserCollectPlayList)\
                    .filter_by(uid=self._uid,
                               vin=self._vin,
                               playlistid=playlistid,
                               selflist=selflist).first()
            else:
                collect = self._conn.session.query(base.UserCollectPlayList)\
                    .filter_by(uid=self._uid,
                               playlistid=playlistid,
                               selflist=selflist).first()
            if collect is None:
                if selflist:
                    if self._uid is None:
                        playlist = self._conn.session.query(base.UserPlayList)\
                            .filter_by(uid=self._uid,
                                       vin=self._vin,
                                       playlistid=playlistid).first()
                    else:
                        playlist = self._conn.session.query(base.UserPlayList) \
                            .filter_by(uid=self._uid,
                                       playlistid=playlistid).first()
                    if playlist is None:
                        return 'No %s in self playlist!' %playlistid
                    else:
                        imageS = playlist.imageSmall
                        imageM = playlist.imageMiddle
                        imageL = playlist.imageLagre
                        playlistname = playlist.playlistname
                else:
                    s = {'ids': playlistid}
                    playlist = demand_api.TracksGetbatch(s).get()[0]
                    imageS = playlist['cover_url_small']
                    imageM = playlist['cover_url_middle']
                    imageL = playlist['cover_url_large']
                    playlistname = playlist['album_title']
                data = {'uid': self._uid,
                        'vin': self._vin,
                        'playlistid': playlistid,
                        'playlistname': playlistname,
                        'imageSmall': imageS,
                        'imageMiddle': imageM,
                        'imageLarge': imageL,
                        'favorite': False,
                        'time': time_array,
                        'selflist': selflist}
                add_item = (base.UserCollectPlayList(**data))
                self._conn.session.add(add_item)
            else:
                collect.favorite = False
                collect.vin = self._vin
                collect.time = time_array
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('cancel failre')
            return False


class UserPlaylist(Common):
    def __init__(self, vin, uid=None, Conn=Connection):
        super(UserPlaylist, self).__init__(vin, uid, Conn)

    def get(self):
        try:
            query = self._conn.session.query(base.UserPlayList)
            if self._uid is None:
                data = query.filter_by(vin=self._vin, uid=self._uid).all()
            else:
                data = query.filter_by(uid=self._uid).all()
            out = [{'playlistid': i.playlistid,
                    'playlistname': i.playlistname,
                    'imageS': i.imageSmall,
                    'imageM': i.imageMiddle,
                    'imageL': i.imageLarge} for i in data]
            self._conn.close()
            return out
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            return False

    def create(self,playlistname):
        try:
            data = {'playlistname': playlistname,
                    'vin': self._vin,
                    'uid': self._uid,
                    'createtime': datetime.datetime.now(),
                    'favorite': False}
            playlist = base.UserPlayList(**data)
            self._conn.session.add(playlist)
            self._conn.session.commit()
            self._conn.close()
            return {'playlistid': playlist.playlistid}
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            return False

    def add(self, timestamp, playlistid, track_id):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            playlist = self._conn.session.query(base.UserPlayList).filter_by(playlistid=playlistid).first()
            if playlist is None:
                return False
            playlistcontent = self._conn.session.query(base.UserPlayListContent) \
                .filter_by(playlistid=playlistid,
                           track_id=track_id).first()
            if playlistcontent is None:
                track = self._conn.session.query(base.Track).filter_by(track_id=track_id).first()
                if track is None:
                    s = {'ids': track_id}
                    trackdata = demand_api.TracksGetbatch(s).get()['tracks'][0]
                    track_title = trackdata['track_title']
                    announcer_id = trackdata['announcer']['id']
                    nickname = trackdata['announcer']['nickname']
                    category_id = trackdata['category_id']
                    album_id = trackdata['subordinated_album']['id']
                    album_title = trackdata['subordinated_album']['album_title']
                    play_count = trackdata['play_count']
                    comment_count = trackdata['comment_count']
                    imageS = trackdata['cover_url_small']
                    imageM = trackdata['cover_url_middle']
                    imageL = trackdata['cover_url_large']
                    duration = trackdata['duration']
                    addtrack = {'track_id': track_id,
                                'track_title': track_title,
                                'announcer_id': announcer_id,
                                'nickname': nickname,
                                'category_id': category_id,
                                'album_id': album_id,
                                'album_title': album_title,
                                'play_count': play_count,
                                'imageSmall': imageS,
                                'imageMiddle': imageM,
                                'imageLarge': imageL,
                                'comment_count': comment_count,
                                'duration': duration}
                    newtrack = base.Track(**addtrack)
                    self._conn.session.add(newtrack)
                else:
                    track_title = track.track_title
                    imageS = track.imagepathmapSmall
                    imageM = track.imagepathmapMiddle
                    imageL = track.imagepathmapLarge
                valid = True
                data = {'playlistid': playlistid,
                        'track_id': track_id,
                        'track_title': track_title,
                        'valid': valid,
                        'time': time_array}
                additem = base.UserPlayListContent(**data)
                playlist.imageSmall = imageS
                playlist.imageMiddle = imageM
                playlist.imageLagre = imageL
                self._conn.session.add(additem)
            else:
                playlistcontent.valid = True
                playlistcontent.vin = self._vin
                playlistcontent.time = time_array
            playlist.modifiedtime = time_array
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('add failre')
            return False

    def cancel(self, timestamp, playlistid, track_id):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            playlist = self._conn.session.query(base.UserPlayList).filter_by(playlistid=playlistid).first()
            if playlist is None:
                return False
            playlistcontent = self._conn.session.query(base.UserPlayListContent) \
                .filter_by(playlistid=playlistid, track_id=track_id).first()
            if playlistcontent is None:
                track = self._conn.session.query(base.Track).filter_by(track_id=track_id).first()
                if track is None:
                    s = {'ids': track_id}
                    trackdata = demand_api.TracksGetbatch(s).get()['tracks'][0]
                    track_title = trackdata['track_title']
                    announcer_id = trackdata['announcer']['id']
                    nickname = trackdata['announcer']['nickname']
                    category_id = trackdata['category_id']
                    album_id = trackdata['subordinated_album']['id']
                    album_title = trackdata['subordinated_album']['album_title']
                    play_count = trackdata['play_count']
                    comment_count = trackdata['comment_count']
                    imageS = trackdata['cover_url_small']
                    imageM = trackdata['cover_url_middle']
                    imageL = trackdata['cover_url_large']
                    duration = trackdata['duration']
                    addtrack = {'track_id': track_id,
                                'track_title': track_title,
                                'announcer_id': announcer_id,
                                'nickname': nickname,
                                'category_id': category_id,
                                'album_id': album_id,
                                'album_title': album_title,
                                'play_count': play_count,
                                'imageSmall': imageS,
                                'imageMiddle': imageM,
                                'imageLarge': imageL,
                                'comment_count': comment_count,
                                'duration': duration}
                    newtrack = base.Track(**addtrack)
                    self._conn.session.add(newtrack)
                else:
                    track_title = track.track_title
                valid = False
                data = {'playlistid': playlistid,
                        'track_id': track_id,
                        'track_title': track_title,
                        'valid': valid,
                        'time': time_array}
                additem = base.UserPlayListContent(**data)
                self._conn.session.add(additem)
            else:
                playlistcontent.valid = False
                playlistcontent.time = time_array
            playlist.modifiedtime = time_array
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('cancel failre')
            return False

    def getplaylistcontent(self, playlistid):
        try:
            query = self._conn.session.query(base.UserPlayListContent)
            data = query.filter_by(playlistid=playlistid,
                                   valid=True).order_by(base.UserPlayListContent.time.desc())
            if data:
                out = [{'track_id': i.track_id, 'track_title': i.track_title}
                       for i in data]
            else:
                out = []
            return out
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('getplaylistcontent failre')
            return False


class UserHistoryBase(object):
    def __init__(self, conn=Connection):
        self._conn = conn

    def getuid(self):
        query = ("SELECT "
                 "DISTINCT tb_tracks_history.uid "
                 "from tb_tracks_history "
                 "where tb_tracks_history.uid<>'';")
        uid = self._conn.session.execute(query)
        self._conn.close()
        return uid

    def getvin(self):
        query = ("SELECT "
                 "DISTINCT tb_tracks_history.vin "
                 "from tb_tracks_history "
                 "where ISNULL(tb_tracks_history.uid);")
        vin = self._conn.session.execute(query)
        self._conn.close()
        return vin


class CollectAlbum(Common):
    def __init__(self, vin, uid=None, conn=Connection):
        super(CollectAlbum, self).__init__(vin, uid, conn)

    def get(self):
        try:
            query = self._conn.session.query(base.UserCollectAlbum)
            if self._uid is None:
                data = query.filter_by(vin=self._vin,
                                       uid=self._uid,
                                       favorite=True).all()
            else:
                data = query.filter_by(uid=self._uid, favorite=True).all()
            out = [{'album_id': i.album_id,
                    'album_title': i.album_title,
                    'cover_url_small': i.cover_url_small,
                    'cover_url_middle': i.cover_url_middle,
                    'cover_url_large': i.cover_url_large,
                    'time': json.dumps(i.time, cls=DateEncoder)} for i in data]
            self._conn.close()
            return out
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('get failre')
            return False

    def add(self, timestamp, album_id, selflist=False):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            if self._uid is None:
                collect = self._conn.session.query(base.UserCollectAlbum)\
                    .filter_by(uid=self._uid,
                               vin=self._vin,
                               album_id=album_id,
                               selflist=selflist).first()
            else:
                collect = self._conn.session.query(base.UserCollectAlbum)\
                    .filter_by(uid=self._uid,
                               album_id=album_id,
                               selflist=selflist).first()
            if collect is None:
                s = {'album_id': album_id}
                album = demand_api.AlbumsBrowse(s).get()
                cover_url_small = album['cover_url_small']
                cover_url_middle = album['cover_url_middle']
                cover_url_large = album['cover_url_large']
                album_title = album['album_title']
                data = {'uid': self._uid,
                        'vin': self._vin,
                        'album_id': album_id,
                        'album_title': album_title,
                        'cover_url_small': cover_url_small,
                        'cover_url_middle': cover_url_middle,
                        'cover_url_large': cover_url_large,
                        'favorite': True,
                        'time': time_array,
                        'selflist': selflist}
                add_item = (base.UserCollectAlbum(**data))
                self._conn.session.add(add_item)
            else:
                collect.favorite = True
                collect.vin = self._vin
                collect.time = time_array
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('add failre')
            return False

    def cancel(self, timestamp, album_id, selflist=False):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            if self._uid is None:
                collect = self._conn.session.query(base.UserCollectAlbum)\
                    .filter_by(uid=self._uid,
                               vin=self._vin,
                               album_id=album_id,
                               selflist=selflist).first()
            else:
                collect = self._conn.session.query(base.UserCollectAlbum)\
                    .filter_by(uid=self._uid,
                               album_id=album_id,
                               selflist=selflist).first()
            if collect is None:
                s = {'album_id': album_id}
                album = demand_api.AlbumsBrowse(s).get()
                cover_url_small = album['cover_url_small']
                cover_url_middle = album['cover_url_middle']
                cover_url_large = album['cover_url_large']
                album_title = album['album_title']
                data = {'uid': self._uid,
                        'vin': self._vin,
                        'album_id': album_id,
                        'album_title': album_title,
                        'cover_url_small': cover_url_small,
                        'cover_url_middle': cover_url_middle,
                        'cover_url_large': cover_url_large,
                        'favorite': False,
                        'time': time_array,
                        'selflist': selflist}
                add_item = (base.UserCollectAlbum(**data))
                self._conn.session.add(add_item)
            else:
                collect.favorite = False
                collect.vin = self._vin
                collect.time = time_array
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('cancel failre')
            return False


class CollectRadio(Common):
    def __init__(self, vin, uid=None, conn=Connection):
        super(CollectRadio, self).__init__(vin, uid, conn)

    def get(self):
        try:
            query = self._conn.session.query(base.UserCollectRadio)
            if self._uid is None:
                data = query.filter_by(vin=self._vin,
                                       uid=self._uid,
                                       favorite=True).all()
            else:
                data = query.filter_by(uid=self._uid, favorite=True).all()
            out = [{'id': i.id,
                    'radio_name': i.radio_name,
                    'cover_url_small': i.cover_url_small,
                    # 'cover_url_middle': i.cover_url_middle,
                    'cover_url_large': i.cover_url_large,
                    'time': json.dumps(i.time, cls=DateEncoder)} for i in data]
            self._conn.close()
            return out
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('get failre')
            return False

    def add(self, timestamp, id, selflist=False):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            if self._uid is None:
                collect = self._conn.session.query(base.UserCollectRadio)\
                    .filter_by(uid=self._uid,
                               vin=self._vin,
                               id=id,
                               selflist=selflist).first()
            else:
                collect = self._conn.session.query(base.UserCollectRadio)\
                    .filter_by(uid=self._uid,
                               id=id,
                               selflist=selflist).first()
            if collect is None:
                s = {'ids': id}
                radio = live_api.LiveGetradiosbyids(s).get()['radios'][0]
                cover_url_small = radio['cover_url_small']
                # cover_url_middle = radio['cover_url_middle']
                cover_url_large = radio['cover_url_large']
                radio_name = radio['radio_name']
                data = {'uid': self._uid,
                        'vin': self._vin,
                        'id': id,
                        'radio_name': radio_name,
                        'cover_url_small': cover_url_small,
                        # 'cover_url_middle': cover_url_middle,
                        'cover_url_large': cover_url_large,
                        'favorite': True,
                        'time': time_array,
                        'selflist': selflist}
                add_item = (base.UserCollectRadio(**data))
                self._conn.session.add(add_item)
            else:
                collect.favorite = True
                collect.vin = self._vin
                collect.time = time_array
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('add failre')
            return False

    def cancel(self, timestamp, id, selflist=False):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            if self._uid is None:
                collect = self._conn.session.query(base.UserCollectRadio)\
                    .filter_by(uid=self._uid,
                               vin=self._vin,
                               id=id,
                               selflist=selflist).first()
            else:
                collect = self._conn.session.query(base.UserCollectRadio)\
                    .filter_by(uid=self._uid,
                               id=id,
                               selflist=selflist).first()
            if collect is None:
                s = {'ids': id}
                radio = live_api.LiveGetradiosbyids(s).get()
                cover_url_small = radio['cover_url_small']
                # cover_url_middle = radio['cover_url_middle']
                cover_url_large = radio['cover_url_large']
                radio_name = radio['radio_name']
                data = {'uid': self._uid,
                        'vin': self._vin,
                        'id': id,
                        'radio_name': radio_name,
                        'cover_url_small': cover_url_small,
                        # 'cover_url_middle': cover_url_middle,
                        'cover_url_large': cover_url_large,
                        'favorite': False,
                        'time': time_array,
                        'selflist': selflist}
                add_item = (base.UserCollectRadio(**data))
                self._conn.session.add(add_item)
            else:
                collect.favorite = False
                collect.vin = self._vin
                collect.time = time_array
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('cancel failre')
            return False


class CollectAnnouncer(Common):
    def __init__(self, vin, uid=None, conn=Connection):
        super(CollectAnnouncer, self).__init__(vin, uid, conn)

    def get(self):
        try:
            query = self._conn.session.query(base.UserCollectAnnouncer)
            if self._uid is None:
                data = query.filter_by(vin=self._vin,
                                       uid=self._uid,
                                       favorite=True).all()
            else:
                data = query.filter_by(uid=self._uid, favorite=True).all()
            out = [{'id': i.id,
                    'nickname': i.nickname,
                    'avatar_url': i.avatar_url} for i in data]
            self._conn.close()
            return out
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('get failre')
            return False

    def add(self, timestamp, id, selflist=False):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            if self._uid is None:
                collect = self._conn.session.query(base.UserCollectAnnouncer)\
                    .filter_by(uid=self._uid,
                               vin=self._vin,
                               id=id,
                               selflist=selflist).first()
            else:
                collect = self._conn.session.query(base.UserCollectAnnouncer)\
                    .filter_by(uid=self._uid,
                               id=id,
                               selflist=selflist).first()
            if collect is None:
                s = {'ids': id}
                announcer = ann.AnnouncersGetbatch(s).get()[0]
                avatar_url = announcer['avatar_url']
                nickname = announcer['nickname']
                data = {'uid': self._uid,
                        'vin': self._vin,
                        'id': id,
                        'nickname': nickname,
                        'avatar_url': avatar_url,
                        'favorite': True,
                        'time': time_array,
                        'selflist': selflist}
                add_item = (base.UserCollectAnnouncer(**data))
                self._conn.session.add(add_item)
            else:
                collect.favorite = True
                collect.vin = self._vin
                collect.time = time_array
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('add failre')
            return False

    def cancel(self, timestamp, id, selflist=False):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            if self._uid is None:
                collect = self._conn.session.query(base.UserCollectAnnouncer)\
                    .filter_by(uid=self._uid,
                               vin=self._vin,
                               id=id,
                               selflist=selflist).first()
            else:
                collect = self._conn.session.query(base.UserCollectAnnouncer)\
                    .filter_by(uid=self._uid,
                               id=id,
                               selflist=selflist).first()
            if collect is None:
                s = {'ids': id}
                announcer = ann.AnnouncersGetbatch(s).get()[0]
                avatar_url = announcer['avatar_url']
                nickname = announcer['nickname']
                data = {'uid': self._uid,
                        'vin': self._vin,
                        'id': id,
                        'nickname': nickname,
                        'avatar_url': avatar_url,
                        'favorite': False,
                        'time': time_array,
                        'selflist': selflist}
                add_item = (base.UserCollectAnnouncer(**data))
                self._conn.session.add(add_item)
            else:
                collect.favorite = False
                collect.vin = self._vin
                collect.time = time_array
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('cancel failre')
            return False


class UserTrackRecord(Common):
    def __init__(self, vin, uid=None, conn=Connection):
        super(UserTrackRecord, self).__init__(vin, uid, conn)

    def get_track(self, album_id):
        try:
            query = self._conn.session.query(base.UserTrackRecord)
            if self._uid is None:
                data = query.filter_by(vin=self._vin,
                                       uid=self._uid,
                                       album_id=album_id).all()
            else:
                data = query.filter_by(uid=self._uid,
                                       album_id=album_id).all()
            out = [{'track_id': i.track_id} for i in data]
            self._conn.close()
            return out
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('get failre')
            return False

    def get_position(self, track_id):
        try:
            query = self._conn.session.query(base.UserTrackRecord)
            if self._uid is None:
                data = query.filter_by(vin=self._vin,
                                       uid=self._uid,
                                       track_id=track_id).all()
            else:
                data = query.filter_by(uid=self._uid,
                                       track_id=track_id).all()
            out = [{'duration': i.position,
                    'time': i.time.strftime("%Y-%m-%d %H:%M:%S")} for i in data]
            self._conn.close()
            return out
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('get failre')
            return False


    def get(self, album_id):
        try:
            query = self._conn.session.query(base.UserTrackRecord)
            if self._uid is None:
                data = query.filter_by(vin=self._vin,
                                       uid=self._uid,
                                       album_id=album_id).all()
            else:
                data = query.filter_by(uid=self._uid,
                                       album_id=album_id).all()
            out = [{'duration': i.position, 'track_id': i.track_id,
                    'time': i.time.strftime("%Y-%m-%d %H:%M:%S")} for i in data]
            self._conn.close()
            return out
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('get failre')
            return False

    def add(self, timestamp, album_id, track_id, position):
        try:
            time_array = datetime.datetime.fromtimestamp(timestamp)
            data = {'uid': self._uid,
                    'vin': self._vin,
                    'album_id': album_id,
                    'track_id': track_id,
                    'position': position,
                    'time': time_array}
            add_item = (base.UserTrackRecord(**data))
            self._conn.session.add(add_item)
            self._conn.commit()
            self._conn.close()
            return True
        except:
            self._conn.session.rollback()
            self._conn.close()
            traceback.print_exc()
            print('add failre')
            return False



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/5/3 上午10:58
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : vendor
# @File    : app_music
# @Contact : guangze.yu@foxmail.com
"""

# aiting API config
import pymysql
conn = pymysql
db = pymysql.connect(host="rm-uf6lp85qe22m65cu6oo.mysql.rds.aliyuncs.com",
                     user="root",
                     password="Root1q2w",
                     db="db_voice",
                     port=3306)
cur = db.cursor()
query = "select * from serverhost;"
cur.execute(query)
results = cur.fetchall()[0]


# API token config
local_token_url = 'http://localhost:8000/gettoken'
remote_token_url = '%s/gettoken' % results[0]



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class ProfileUserinfo(Common):
    '''根据用户ID获取用户基本信息'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:uid.
        uid:当前用户ID
        '''
        
        assert 'uid' in param_dict.keys(), 'There is no uid in the given params!'
        super(ProfileUserinfo, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/profile/user_info'

class ProfilePersona(Common):
    '''根据用户ID获取用户画像资料'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:uid.
        uid:当前用户ID
        '''
        
        assert 'uid' in param_dict.keys(), 'There is no uid in the given params!'
        super(ProfilePersona, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/profile/persona'


#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class SearchAlbums(Common):
    '''搜索专辑'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:q; 可选:category_id,calc_dimension,page,count.
        q:搜索关键词
        category_id:分类ID,指定分类,为0时表示热门分类
        calc_dimension:排序条件:2-最新,3-最多播放,4-最相关(默认)
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'q' in param_dict.keys(), 'There is no search word in the given params!'
        super(SearchAlbums, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/search/albums'

class SearchTracks(Common):
    '''搜索声音'''
    def __init__(self, param_dict):
        '''
        :param param_dict: q:search word category_id: ID of category calc_dimension: sorted condition(2~4).
        参数:除公共参数外,必须包含:q; 可选:category_id,calc_dimension,page,count.
        q:搜索关键词
        category_id:分类ID,指定分类,为0时表示热门分类
        calc_dimension:排序条件:2-最新,3-最多播放,4-最相关(默认)
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'q' in param_dict.keys(), 'There is no search word in the given params!'
        super(SearchTracks, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/search/tracks'

class SearchHotwords(Common):
    '''获取最新热搜词'''
    def __init__(self,param_dict):
        '''
        参数:除公共参数外,必须包含:top.
        top:获取前top长度的热搜词.(1<=top<=20:目前top只支持最多20个)
        '''
        
        assert 'top' in param_dict.keys(), 'There is no top length in the given params!'
        super(SearchHotwords, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/search/hot_words'

class SearchSuggestwords(Common):
    '''获取某个关键词的联想词'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:q.
        q:搜索查询词参数
        '''
        
        assert 'q' in param_dict.keys(), 'There is no search word in the given params!'
        super(SearchSuggestwords, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/search/suggest_words'

class SearchRadios(Common):
    '''按照关键词搜索直播'''
    def __init__(self,param_dict):
        '''
        参数:除公共参数外,必须包含:q; 可选:radio_category_id,area,lnt,lat,outer_ip,count,page.
        q:搜索查询词参数
        radio_category_id:直播分类ID
        area:搜索地区参数.如果此参数有值,请在q参数中保留地区关键字以保证搜索质量,比如:q:上海交通广播; area:上海
        lnt:经度参数
        lat:纬度参数
        outer_ip:IP参数,此参数需传公网IP,如果需要根据地理位置查询,则经纬度和IP参数至少传一个
        count:每页多少条,默认20,最多不超过200
        page:分页请求参数,表示请求第几页,默认为1即第一页
        '''
        
        assert 'q' in param_dict.keys(), 'There is no search word in the given params!'
        super(SearchRadios, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/search/radios'

class SearchAnnouncers(Common):
    '''搜索主播'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:q; 可选:calc_dimension,page,count.
        q:搜索查询词参数
        calc_dimension:排序条件:4-最相关(默认),5-粉丝最多,6-声音最多
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'q' in param_dict.keys(), 'There is no search word in the given params!'
        super(SearchAnnouncers, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/search/announcers'

class SearchAll(Common):
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:q; 可选:page,count.
        page:分页请求参数,表示请求第几页,默认为1即第一页
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'q' in param_dict.keys(), 'There is no search word in the given params!'
        super(SearchAll, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/search/all'

class SearchSmartSearch(Common):
    '''智能搜索,可以用于语音搜索场景'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,可选:q,category_id,metadatas,seq,date_range,search_result_list_size,recommend_result_list_size,
                            contains_paid.
        q:搜索关键词,若为空则按分类搜索
        category_id:分类ID,指定分类,为0时表示热门分类
        metadatas:元数据名称,为对应分类的中文名称,可指定多个,中间用英文逗号分隔
        seq:集数约束条件,以s或e开头,后面跟着集数,s代表从前往后,e从后往前.比如s2代表从前往后第二集,e3代表从后往前第三集.若此参数添值,
            搜索结果返回个数为1
        date_range:日期约束条件,格式为yyyy-MM-dd,yyy-MM-dd,其中的逗号为英文逗号,后面日期必须大于等于前面日期.比如2015-01-01,
                   2016-12-31.若此参数填值,搜索结果返回个数为1
        search_result_list_size:指定搜索返回结果的个数.与推荐结果个数之和不超过20.
        recommend_result_list_size:指定推荐返回结果的个数.与搜索结果个数之和不超过20
        contains_paid:是否输出付费专辑
        '''
        
        super(SearchSmartSearch, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/search/smart_search'

# s = {'top':'10'}
# t = SearchHotwords(s).get()
# print(t)

# s = {'q':'高晓松'}
# t = SearchSuggestwords(s).get()
# print(t)

# s = {'q':'高晓松'}
# t = SearchAlbums(s).get()
# print(t)

# s = {'q':'晓说2017'}
# t = SearchTracks(s).get()
# print(t)

# s = {'q':'晓说2017'}
# t = SearchRadios(s).get()
# print(t)

# s = {'q':'高晓松'}
# t = SearchAnnouncers(s).get()
# print(t)

# s = {'q':'高晓松'}
# t = SearchAll(s).get()
# print(t)
# # mp3链接点击无法跳转









#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-27 上午9:07
# @Author  : Enoch.Xiang
# @Site    : shanghai
# @File    : search
# @Contact : xiangwenzhuo@yeah.net
"""

import API.search as api
import logging
import database.data_base as db
import datetime
import traceback
import database.base_init as base
from utils import logger
import utils.decorator as decorator
import utils.result as result
import utils.exception as exception


LOG = logger.get_logger(__name__)
params_check = decorator.params_check

Connection = base.Connect()


@params_check
def hotwords(params):
    '''获取最新热搜词'''
    LOG.info('hotwords service:')
    LOG.info('params is %s' % params)
    try:
        if 'top' in params.keys():
            top = params['top']
            if not len(top):
                return result.ErrorResult(exception.NoTopError())
            text = {'top': top}
            res = api.SearchHotwords(text).get()
            return result.SearchResult(res=res)
        else:
            return result.ErrorResult(exception.NoTopError())
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def suggestwords(params):
    '''获取某个关键词的联想词'''
    LOG.info('searchsuggestwords service')
    LOG.info('params is %s' % params)
    try:
        if 'q' in params.keys():
            q = params['q']
            if not len(q):
                return result.ErrorResult(exception.NoKeyWordError())
            text = {'q': q}
        else:
            return result.ErrorResult(exception.NoKeyWordError())
        res = api.SearchSuggestwords(text).get()
        return result.SearchResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def album(params):
    '''获取专辑'''
    logging.info('searchalbums service')
    logging.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        vin = params['vin']
        if 'q' in params.keys():
            q = params['q']
            text = {'q': q}
        else:
            return result.ErrorResult(exception.NoKeyWordError())
        try:
            his = db.SearchWordHistory(vin, uid=None)
            his.add(timestamp, q)
        except:
            traceback.print_exc()
            logging.exception('this is an data exception message')
        res = api.SearchAlbums(text).get()
        return result.SearchResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def track(params):
    '''获取声音'''
    LOG.info('searchtracks service')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        vin = params['vin']
        if 'q' in params.keys():
            q = params['q']
            text = {'q': q}
        else:
            return result.ErrorResult(exception.NoKeyWordError())
        try:
            his = db.SearchWordHistory(vin, uid=None)
            his.add(timestamp, q)
        except:
            traceback.print_exc()
            logging.exception('this is an data exception message')
        res = api.SearchTracks(text).get()
        return result.SearchResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def radio(params):
    '''获取直播'''
    LOG.info('searchradios service')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        vin = params['vin']
        if 'q' in params.keys():
            q = params['q']
            text = {'q': q}
        else:
            return result.ErrorResult(exception.NoKeyWordError())
        try:
            his = db.SearchWordHistory(vin, uid=None)
            his.add(timestamp, q)
        except:
            traceback.print_exc()
            logging.exception('this is an data exception message')
        res = api.SearchRadios(text).get()
        return result.SearchResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def announcer(params):
    '''获取主播'''
    LOG.info('searchannouncers service')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        vin = params['vin']
        if 'q' in params.keys():
            q = params['q']
            text = {'q': q}
        else:
            return result.ErrorResult(exception.NoKeyWordError())
        try:
            his = db.SearchWordHistory(vin, uid=None)
            his.add(timestamp, q)
        except:
            traceback.print_exc()
            LOG.exception('this is an data exception message')
        res = api.SearchAnnouncers(text).get()
        return result.SearchResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def all(params):
    '''获取指定数量直播，声音，专辑的内容'''
    LOG.info('searchall service')
    LOG.info('params is %s' % params)
    try:
        timestamp = params['timestamp']
        vin = params['vin']
        if 'q' in params.keys():
            q = params['q']
            if not len(q):
                return result.ErrorResult(exception.NoKeyWordError())
            text = {'q': q}
        else:
            return result.ErrorResult(exception.NoKeyWordError())
        try:
            his = db.SearchWordHistory(vin, uid=None)
            his.add(timestamp, q)
        except:
            traceback.print_exc()
            LOG.exception('this is an data exception message')
        res = api.SearchAll(text).get()
        return result.SearchResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def gethistory(params):
    """获取搜索记录"""
    LOG.info('gethistory service:')
    LOG.info('params is %s', params)
    try:
        vin = params['vin']
        uid = params['uid']
        conn = base.Connect()
        end_time = datetime.datetime.now()
        start_time = end_time - datetime.timedelta(180)
        his = db.SearchWordHistory(vin, uid, conn)
        res = his.get(start_time, end_time)
        conn.close()
        return result.SearchResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def clearhistory(params):
    """清空搜索记录"""
    LOG.info('delhistory service:')
    LOG.info('params is %s', params)
    try:
        # info = params
        # message = mess.SearchWordsHistory(method='clear', info=info)
        # res = 'Success.'
        # return result.SearchResult(res=res, message=message)
        vin = params['vin']
        uid = params['uid']
        conn = base.Connect()
        his = db.SearchWordHistory(vin, uid, conn)
        res = his.clear()
        conn.close()
        if res:
            return result.SearchResult(res='Success.')
        return result.ErrorResult(exception.SQLConnectError())
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/5/3 上午11:00
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : rabbitmq
# @File    : app_music
# @Contact : guangze.yu@foxmail.com
"""

# pika config
pika_host = '47.100.225.82'
pika_port = 5672
virtual_host = '/'
pika_username = 'admin'
pika_password = 'Root1q2w'



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-27 上午9:16
# @Author  : Enoch.Xiang
# @Site    : shanghai
# @File    : more
# @Contact : xiangwenzhuo@yeah.net
"""

import utils.result as result
import utils.exception as exception
import utils.decorator as decorator
import time
import traceback
import API.demand as dem
import API.live as live
import API.announcers as ann
import logger
import app.collect as col
import app.playhistory as his
import rec.recommend as rec
import database.data_base as db
import database.base_init as init
LOG = logger.get_logger(__name__)
params_check = decorator.params_check


def takeTime(elem):
    """
    function: 提取time字段
    :param elem:
    :return:
    """
    return elem['time']


def filters(params):
    """
    function：从推荐的专辑中去掉已收藏的专辑
    :param params: page:系统推荐返回第几页；collect_ids:已收藏专辑的id列表
    :return:
    """
    page = params['page']
    text = {'category_id': 0, 'calc_dimension': 1, 'count': 30, 'page': page}
    album_list = dem.V2AlbumsList(text).get()['albums']
    album_ids = []
    for m in album_list:
        alb_id = str(m['id'])
        album_ids.append(alb_id)
    collect_ids = params['collect_ids']
    show_ids = list(set(album_ids) - set(collect_ids))
    return show_ids


@params_check
def albuminfo(params):
    """
    function: 专辑详情
    :param params:
    page: int 当前第几页，默认1
    count: int 每页多少条，不超过200，默认20
    :return:
        专辑中声音列表
    """
    LOG.info('albuminfo service:')
    LOG.info('params is %s' % params)
    try:
        vin = params['vin']
        if 'uid' in params.keys():
            uid = params['uid']
        else:
            uid = None
        album_id = params['album_id']
        text = {'album_id': album_id}
        res = dem.AlbumsBrowse(text).get()
        try:
            collect_list = col.getcollectalbum(params).response
            collect_ids = []
            for i in collect_list:
                col_id = i['album_id']
                collect_ids.append(col_id)
            album_id = int(album_id)
            if album_id in collect_ids:
                res['isLike'] = True
            else:
                res['isLike'] = False
            conn = init.Connect()
            res['record'] = {}
            record = db.UserTrackRecord(vin, uid, conn).get(album_id)
            record.sort(key=takeTime, reverse=True)
            res['record'] = record[0]
            conn.close()
        except:
            traceback.print_exc()
            LOG.exception('this is an data exception message')
        timestamp = float(params['timestamp'])
        a = time.time() - timestamp
        print('返回时间差%ss' % a)
        return result.MoreInfoResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def radioinfo(params):
    """
    function: 电台详细信息
    :param params:
    page: int 当前第几页，默认1
    count: int 每页多少条，不超过200，默认20
    :return:
    """
    LOG.info('radioinfo service:')
    LOG.info('params is %s' % params)
    try:
        if 'id' in params.keys():
            id = params['id']
            if not len(id):
                return result.ErrorResult(exception.NoIdError())
        else:
            return result.ErrorResult(exception.NoIdError())
        text = {'ids': id, 'radio_id': id}
        res = live.LiveGetradiosbyids(text).get()
        list = live.LiveSchedules(text).get()
        current = live.LiveGetplayingprogram(text).get()
        res['list'] = list
        res['current'] = current
        try:
            collect_list = col.getcollectradio(params).response
            collect_ids = []
            for i in collect_list:
                col_id = i['id']
                collect_ids.append(col_id)
            id = int(id)
            if id in collect_ids:
                res['isLike'] = True
            else:
                res['isLike'] = False
        except:
            traceback.print_exc()
            LOG.exception('this is an data exception message')
        timestamp = float(params['timestamp'])
        a = time.time() - timestamp
        print('返回时间差%ss' % a)
        return result.MoreInfoResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def roewe_rec(params):
    """

    :param params:
    :return:
    """
    LOG.info('roewe_rec service')
    LOG.info('params is %s' % params)
    try:
        vin = params['vin']
        uid = params['uid']
        album_id = rec.RoeweRec(vin, uid).get_recommend()[0]['id']
        params['album_id'] = album_id
        res = albuminfo(params).response
        timestamp = float(params['timestamp'])
        a = time.time() - timestamp
        print('返回时间差%ss' % a)
        return result.MoreInfoResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def announceralbums(params):
    """

    :param params:
    :return:
    """
    LOG.info('announcer albums service')
    LOG.info('param is %s' % params)
    try:
        aid = params['id']
        text = {'aid': aid}
        res = ann.AnnouncersAlbums(text).get()
        timestamp = float(params['timestamp'])
        a = time.time() - timestamp
        print('返回时间差%ss' % a)
        return result.MoreInfoResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError)


@params_check
def announcerinfo(params):
    """

    :param params:
    :return:
    """
    LOG.info('announcer info service')
    LOG.info('param is %s' % params)
    try:
        ids = params['id']
        text = {'ids': ids}
        res = ann.AnnouncersGetbatch(text).get()
        timestamp = float(params['timestamp'])
        a = time.time() - timestamp
        print('返回时间差%ss' % a)
        return result.MoreInfoResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError)


@params_check
def lists(params):
    """

    :param params:
    :return:
    """
    LOG.info('home service:')
    LOG.info('params is %s' % params)
    try:
        vin = params['vin']
        uid = params['uid']
        daily_rec = rec.DailyRec(vin, uid).get_recommend()[0]
        daily_rec['isLike'] = False
        collect_list = col.getcollectalbum(params).response
        collect_list.sort(key=takeTime, reverse=True)
        daily_rec_id = str(rec.DailyRec(vin, uid).get_recommend()[0]['id'])
        collect_ids = [daily_rec_id]
        for i in collect_list:
            col_id = str(i['album_id'])
            collect_ids.append(col_id)
        page = 1
        params['page'] = page
        params['collect_ids'] = collect_ids
        show_ids = filters(params)
        num2 = len(show_ids)
        while num2 < 4:
            page += 1
            params['page'] = page
            show_ids = filters(params)
        ids = ','.join(show_ids)
        body = {'ids': ids}
        show_list = dem.AlbumsGetbatch(body).get()
        num3 = len(collect_list)
        if num3 >= 1:
            if num3 == 1:
                playlist_1 = collect_list[0]
                playlist_1['id'] = collect_list[0]['album_id']
                playlist_2 = show_list[2]
                playlist_1['isLike'] = True
                playlist_2['isLike'] = False
            else:
                playlist_1 = collect_list[0]
                playlist_2 = collect_list[1]
                playlist_1['id'] = collect_list[0]['album_id']
                playlist_2['id'] = collect_list[1]['album_id']
                playlist_1['isLike'] = playlist_2['isLike'] = True
        else:
            playlist_1 = show_list[2]
            playlist_2 = show_list[3]
            playlist_1['isLike'] = playlist_2['isLike'] = False
        params['count'] = 50
        playlist_3 = show_list[0]
        playlist_4 = show_list[1]
        playlist_3['isLike'] = playlist_4['isLike'] = False
        playlist = [playlist_1, playlist_2, playlist_3, playlist_4]
        res = {'album_num': num3, 'daily_rec': daily_rec, 'playlist': playlist}
        timestamp = float(params['timestamp'])
        a = time.time() - timestamp
        print('返回时间差%ss' % a)
        return result.MoreInfoResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


@params_check
def num(params):
    """

    :param params:
    :return:
    """
    LOG.info('num service')
    LOG.info('params is %s' % params)
    try:
        num1 = len(col.getcollecttrack(params).response)
        num2 = len(his.gethistory(params).response)
        res = {'collect_num': num1, 'history_num': num2}
        timestamp = float(params['timestamp'])
        a = time.time() - timestamp
        print('返回时间差%ss' % a)
        return result.MoreInfoResult(res=res)
    except:
        traceback.print_exc()
        return result.ErrorResult(exception.InternalError())


# @params_check
# def home(params):
#     """
#
#     :param params:
#     :return:
#     collect_num: 当前用户收藏声音的数目
#     history_num: 当前用户历史播放数目
#     """
#     LOG.info('home service:')
#     LOG.info('params is %s' % params)
#     try:
#         vin = params['vin']
#         uid = params['uid']
#         text = {'category_id': 0, 'calc_dimension': 1, 'count': 30}
#         roewe_rec = rec.RoeweRec(vin, uid).get_recommend()[0]
#         daily_rec = rec.DailyRec(vin, uid).get_recommend()[0]
#         album_list = dem.V2AlbumsList(text).get()['albums']
#         collect_list = col.getcollectalbum(params).response
#         collect_ids = [roewe_rec['id'], daily_rec['id']]
#         show_list = []
#         for i in collect_list:
#             col_id = i['album_id']
#             collect_ids.append(col_id)
#         for m in album_list:
#             if m['id'] not in collect_ids:
#                 show_list.append(m)
#         data1 = col.getcollecttrack(params).response
#         data2 = his.gethistory(params).response
#         num1, num2, num3 = len(data1), len(data2), len(collect_list)
#         params['count'] = 50
#         playlist_3 = show_list[1]
#         playlist_4 = show_list[2]
#         playlist_3['collect'] = playlist_4['collect'] = 0
#         if num3 >= 1:
#             if num3 == 1:
#                 playlist_1 = collect_list[0]
#                 playlist_1['id'] = collect_list[0]['album_id']
#                 playlist_2 = show_list[0]
#                 playlist_1['collect'] = 1
#                 playlist_2['collect'] = 0
#             else:
#                 playlist_1 = collect_list[0]
#                 playlist_2 = collect_list[1]
#                 playlist_1['collect'] = 1
#                 playlist_2['collect'] = 1
#         else:
#             playlist_1 = show_list[3]
#             playlist_2 = show_list[4]
#             playlist_1['collect'] = playlist_2['collect'] = 0
#         playlist = [playlist_1, playlist_2, playlist_3, playlist_4]
#         res = {'collect_num': num1, 'history_num': num2, 'album_num': num3,
#                'roewe_rec': roewe_rec,
#                'daily_rec': daily_rec, 'playlist': playlist}
#         timestamp = float(params['timestamp'])
#         a = time.time() - timestamp
#         print('返回时间差%ss' % a)
#         return result.MoreInfoResult(res=res)
#     except:
#         traceback.print_exc()
#         return result.ErrorResult(exception.InternalError())



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-26 下午2:32
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : main
# @Contact : guangze.yu@foxmail.com
"""
import tornado.web as web
import tornado.ioloop as ioloop
from tornado.options import options, define
import server.handler as handler
from kazoo.client import KazooClient
from utils import logger
import mq.client as mq_client
import config.zookeeper as zk_config
import config.server as server_config

LOG = logger.get_logger(__name__)
IP = server_config.IP
PORT = server_config.PORT

define('port', default=PORT, type=int, help='Server port')
define('bind', default='0.0.0.0', type=str, help='Server bind')
define('zk_connect',
       default=zk_config.zookeeper_host,
       type=str,
       help='zookeeper connect')


def zk_stats():
    """

    :return:
    """
    if ZK.state == 'LOST':
        LOG.info('zookeeper state:%s', ZK.state)
        ZK.start()


if __name__ == "__main__":
    TestHandler = handler.CommonHandler
    SearchHandler = handler.RoeweVoiceSearchHandler
    CollectHandler = handler.RoeweVoiceCollectHandler
    PlayHandler = handler.RoeweVoicePlayHandler
    PlayListHandler = handler.RoeweVoicePlayListHandler
    PlayHistoryHandler = handler.RoeweVoicePlayHistoryHandler
    MoreInfoHandler = handler.RoeweVoiceMoreInfoHandler
    RecommendHandler = handler.RoeweVoiceRecommendHandler
    AlbumHandler = handler.RoeweVoiceAlbumHandler
    handlers = [(r'/voice/collect/(.*)',CollectHandler),
                (r'/voice/search/(.*)', SearchHandler),
                (r'/voice/play/(.*)', PlayHandler),
                (r'/voice/playlist/(.*)', PlayListHandler),
                (r'/voice/playhistory/(.*)', PlayHistoryHandler),
                (r'/voice/moreinfo/(.*)', MoreInfoHandler),
                (r'/voice/recommend/(.*)', RecommendHandler),
                (r'/voice/album/(.*)', AlbumHandler)]
    app = web.Application(handlers)
    ZK = KazooClient(hosts=options.zk_connect)
    setattr(app, 'options', options)
    app.listen(options.port, address=options.bind)
    ZK.start()
    if ZK.exists('/roewe_server') is None:
        ZK.create('/roewe_server')
    if ZK.exists('/roewe_server/music') is None:
        ZK.create('/roewe_server/music')
    if ZK.exists('/roewe_server/music/%s:%s' % (IP, options.port)) is None:
        ZK.create(path='/roewe_server/music/%s:%s' % (IP, options.port), ephemeral=True)
    ioloop.PeriodicCallback(zk_stats, 100000).start()
    main_loop = ioloop.IOLoop.instance()
    mq_conn = mq_client.PikaClient(main_loop)
    setattr(app, 'mq', mq_conn)
    main_loop.start()
    ioloop.IOLoop.instance().start()


#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class CustomizedCategories(Common):
    '''获取喜马拉雅提供的由合作方自定义图标的内容分类'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:icon_set_id.
        icon_set_id:定制化的图标集ID
        '''
        
        assert 'icon_set_id' in param_dict.keys(), 'There is no icon_set_id in the given params!'
        super(CustomizedCategories, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/customized/categories'

class CustomizedTracks(Common):
    '''获取合作方定制化的声音列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:customized_tracklist_id; 可选:page,count.
        customized_tracklist_id:定制化的声音集ID
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'customized_tracklist_id' in param_dict.keys(), 'There is no customized_tracklist_id in the given params!'
        super(CustomizedTracks, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/customized/tracks'

class V2CustomizedAlbumcolumns(Common):
    '''根据搜索条件和分页参数,获取符合条件的合作方自定制的专辑类听单'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,可选:publish_date_start,publish_date_end,dimensions,with_dimensions,page,count.
        publish_date_start:发布起始日期,与publish_date_end一起组成日期区间,限定只返回指定发布时间区间内的内容详情,
                           格式为”yyyyMMdd”,比如”20161123”.publish_date_start与publish_date_end必须成对出现.
        publish_date_end:发布截止日期,与publish_date_start一起组成日期区间,限定只返回指定发布时间区间内的内容详情,
                         格式为”yyyyMMdd”,比如”20161124” publish_date_start与publish_date_end必须成对出现.
        dimensions:维度(在自运营内容网站上配置)过滤参数,限定只返回满足维度过滤条件的听单内容详情.格式为:dimId1:dimVal1;
                   dimId2:dimVal2 ,比如有一个ID为1的维度表示孕期第几天,有一个ID为2的维度表示内容标签,则可以有”1:7;2:音乐”,
                   返回的是孕期第7天且内容标签为音乐的内容详情
        with_dimensions:返回值是否带上维度配置数据,不填则默认为false
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        super(V2CustomizedAlbumcolumns, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/v2/customized/album_columns'

class V2CustomizedTrackcolumns(Common):
    '''根据搜索条件和分页参数,获取符合条件的合作方自定制的声音类听单'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,可选:publish_date_start,publish_date_end,dimensions,with_dimensions,page,count.
        publish_date_start:发布起始日期,与publish_date_end一起组成日期区间,限定只返回指定发布时间区间内的内容详情,
                           格式为”yyyyMMdd”,比如”20161123”.publish_date_start与publish_date_end必须成对出现.
        publish_date_end:发布截止日期,与publish_date_start一起组成日期区间,限定只返回指定发布时间区间内的内容详情,
                         格式为”yyyyMMdd”,比如”20161124” publish_date_start与publish_date_end必须成对出现.
        dimensions:维度(在自运营内容网站上配置)过滤参数,限定只返回满足维度过滤条件的听单内容详情.格式为:dimId1:dimVal1;
                   dimId2:dimVal2 ,比如有一个ID为1的维度表示孕期第几天,有一个ID为2的维度表示内容标签,则可以有”1:7;2:音乐”,
                   返回的是孕期第7天且内容标签为音乐的内容详情
        with_dimensions:返回值是否带上维度配置数据,不填则默认为false
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        super(V2CustomizedTrackcolumns, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/v2/customized/track_columns'

class V2CustomizedAlbumcolumndetail(Common):
    '''根据搜索条件和分页参数,获取自定义专辑听单内容详情.'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:id;
            可选:category_id,paid_filter_type,publish_date_start,publish_date_end,dimensions,with_dimensions,page,count.
        id:自定义专辑听单ID
        category_id:分类ID,如果设置了则限制只返回指定分类下的内容详情
        paid_filter_type:付费专辑过滤字段,-1 –无此属性,0 –免费专辑,1 –付费专辑.如果不传该字段,则不根据该字段过滤.
        publish_date_start:发布起始日期,与publish_date_end一起组成日期区间,限定只返回指定发布时间区间内的内容详情,
                           格式为”yyyyMMdd”,比如”20161123”.publish_date_start与publish_date_end必须成对出现.
        publish_date_end:发布截止日期,与publish_date_start一起组成日期区间,限定只返回指定发布时间区间内的内容详情,
                         格式为”yyyyMMdd”,比如”20161124” publish_date_start与publish_date_end必须成对出现.
        dimensions:维度(在自运营内容网站上配置)过滤参数,限定只返回满足维度过滤条件的听单内容详情.格式为:dimId1:dimVal1;
                   dimId2:dimVal2 ,比如有一个ID为1的维度表示孕期第几天,有一个ID为2的维度表示内容标签,则可以有”1:7;2:音乐”,
                   返回的是孕期第7天且内容标签为音乐的内容详情
        with_dimensions:返回值是否带上维度配置数据,不填则默认为false
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'id' in param_dict.keys(), 'There is no id in the given params!'
        super(V2CustomizedAlbumcolumndetail, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/v2/customized/album_column_detail'

class V2CustomizedTrackcolumndetail(Common):
    '''根据搜索条件和分页参数,获取自定义声音听单内容详情.'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:id;
            可选:category_id,publish_date_start,publish_date_end,dimensions,with_dimensions,page,count.
        id:自定义专辑听单ID
        category_id:分类ID,如果设置了则限制只返回指定分类下的内容详情
        publish_date_start:发布起始日期,与publish_date_end一起组成日期区间,限定只返回指定发布时间区间内的内容详情,
                           格式为”yyyyMMdd”,比如”20161123”.publish_date_start与publish_date_end必须成对出现.
        publish_date_end:发布截止日期,与publish_date_start一起组成日期区间,限定只返回指定发布时间区间内的内容详情,
                         格式为”yyyyMMdd”,比如”20161124” publish_date_start与publish_date_end必须成对出现.
        dimensions:维度(在自运营内容网站上配置)过滤参数,限定只返回满足维度过滤条件的听单内容详情.格式为:dimId1:dimVal1;
                   dimId2:dimVal2 ,比如有一个ID为1的维度表示孕期第几天,有一个ID为2的维度表示内容标签,则可以有”1:7;2:音乐”,
                   返回的是孕期第7天且内容标签为音乐的内容详情
        with_dimensions:返回值是否带上维度配置数据,不填则默认为false
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'id' in param_dict.keys(), 'There is no id in the given params!'
        super(V2CustomizedTrackcolumndetail, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/v2/customized/track_column_detail'

class CustomizedSearchtracks(Common):
    '''根据搜索条件和分页参数,搜索所有声音听单下符合条件的声音列表.'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,可选:q,category_id,publish_date_start,publish_date_end,dimensions,with_dimensions,page,count.
        q:搜索关键词,如果设置了则限制只返回满足关键词过滤条件的听单内容详情
        category_id:分类ID,如果设置了则限制只返回指定分类下的内容详情
        publish_date_start:发布起始日期,与publish_date_end一起组成日期区间,限定只返回指定发布时间区间内的内容详情,
                           格式为”yyyyMMdd”,比如”20161123”.publish_date_start与publish_date_end必须成对出现.
        publish_date_end:发布截止日期,与publish_date_start一起组成日期区间,限定只返回指定发布时间区间内的内容详情,
                         格式为”yyyyMMdd”,比如”20161124” publish_date_start与publish_date_end必须成对出现.
        dimensions:维度(在自运营内容网站上配置)过滤参数,限定只返回满足维度过滤条件的听单内容详情.格式为:dimId1:dimVal1;
                   dimId2:dimVal2 ,比如有一个ID为1的维度表示孕期第几天,有一个ID为2的维度表示内容标签,则可以有”1:7;2:音乐”,
                   返回的是孕期第7天且内容标签为音乐的内容详情
        with_dimensions:返回值是否带上维度配置数据,不填则默认为false
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        super(CustomizedSearchtracks, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/customized/search_tracks'

class CustomizedTrackdetail(Common):
    '''根据声音ID和该声音所属声音听单ID获取声音详情'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:track_id,track_column_id; 可选:with_dimensions.
        track_id:声音ID
        track_column_id:声音所属听单ID
        with_dimensions:返回值是否带上维度配置数据,不填则默认为false
        '''
        
        assert 'track_id' in param_dict.keys(), 'There is no track_id in the given params!'
        assert 'track_column_id' in param_dict.keys(), 'There is no track_column_id in the given params!'
        super(CustomizedTrackdetail, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/customized/track_detail'

class CustomizedSearchalbumsortrackcolumns(Common):
    '''根据搜索条件和分页参数,搜索所有专辑或声音听单,返回结果已去重'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:result_content_type; 可选:q,category_id,paid_filter_type,publish_date_start,
            publish_date_end,dimension_filter_type,dimensions,calc_dimensions,with_dimensions,page,count.
        result_content_type:搜索结果内容类型:album-专辑,trackColumn-声音听单
        q:搜索关键词,如果设置了则限制只返回满足关键词过滤条件的听单内容详情
        category_id:分类ID,如果设置了则限制只返回指定分类下的内容详情
        paid_filter_type:付费专辑过滤字段,-1 –无此属性,0 –免费专辑,1 –付费专辑.如果不传该字段,则不根据该字段过滤.
        publish_date_start:发布起始日期,与publish_date_end一起组成日期区间,限定只返回指定发布时间区间内的内容详情,
                           格式为”yyyyMMdd”,比如”20161123”.publish_date_start与publish_date_end必须成对出现.
        publish_date_end:发布截止日期,与publish_date_start一起组成日期区间,限定只返回指定发布时间区间内的内容详情,
                         格式为”yyyyMMdd”,比如”20161124” publish_date_start与publish_date_end必须成对出现.

        dimensions_filter_type:维度过滤类型:1-交集,2-并集. 默认交集.
        dimensions:维度(在自运营内容网站上配置)过滤参数,限定只返回满足维度过滤条件的听单内容详情.格式为:dimId1:dimVal1;
                   dimId2:dimVal2 ,比如有一个ID为1的维度表示孕期第几天,有一个ID为2的维度表示内容标签,则可以有”1:7;2:音乐”,
                   返回的是孕期第7天且内容标签为音乐的内容详情
        calc_dimensions:返回结果排序维度:2-最新创建在前,3-最多播放在前,默认为2.
        with_dimensions:返回值是否带上维度配置数据,不填则默认为false
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'result_content_type' in param_dict.keys(), 'There is no result_content_type in the given params!'
        super(CustomizedSearchalbumsortrackcolumns, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/customized/search_albums_or_track_columns'



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 2017/10/20 10:19
# @Author  : guangze.yu/LiShuo
# @Site    : shanghai
# @File    : ximalayaAPI.py
# @Contact : guangze.yu@foxmail.com
"""

import API.common as common

Common = common.Common

class RanksIndexlist(Common):
    '''根据榜单类型获取榜单首页的榜单列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:rank_type.
        rank_type:榜单类型,1-节目榜单
        '''
        
        assert 'rank_type' in param_dict.keys(), 'There is no rank_type in the given params!'
        super(RanksIndexlist, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/ranks/index_list'

class RanksAlbums(Common):
    '''根据rank_key获取某个榜单下的专辑列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:rank_key; 可选:page,count.
        rank_key:用于获取具体榜单内容的key,可以先通过/rank/index_list获得
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'rank_key' in param_dict.keys(), 'There is no rank_key in the given params!'
        super(RanksAlbums, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/ranks/albums'

class RanksTracks(Common):
    '''根据rank_key获取某个榜单下的声音列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:rank_key; 可选:page,count.
        rank_key:用于获取具体榜单内容的key,可以先通过/rank/index_list获得
        page:返回第几页,必须大于等于1,不填默认为1
        count:每页多少条,默认20,最多不超过200
        '''
        
        assert 'rank_key' in param_dict.keys(), 'There is no rank_key in the given params!'
        super(RanksTracks, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/ranks/tracks'

class RanksRadios(Common):
    '''根据rank_key获取某个榜单下的声音列表'''
    def __init__(self, param_dict):
        '''
        参数:除公共参数外,必须包含:radio_count.
        radio_count:需要获取排行榜中的电台数目
        '''
        
        assert 'radio_count' in param_dict.keys(), 'There is no radio_count in the given params!'
        super(RanksRadios, self).__init__()
        self._param_private = param_dict
        self._url = 'http://api.ximalaya.com/ranks/radios'

#
# s = {'rank_type': 1}
# res = RanksIndexlist(s).get()
# print(res)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 18-1-11 上午9:16
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : base_init
# @Contact : guangze.yu@foxmail.com
"""
from sqlalchemy import Column, String, Integer, create_engine, TEXT, Boolean, DateTime
from sqlalchemy.orm import sessionmaker
from sqlalchemy.ext.declarative import declarative_base
import database.config as cfg
import random
import datetime
import API.ranks as ranks_api
import logger

log = logger.get_logger(__name__)

Base = declarative_base()


class Connect():
    '''
    database connect:
    '''
    def __init__(self, config=cfg.sqlconfig):
        self.engine = create_engine(config,encoding='utf-8')
        DBSession = sessionmaker(bind=self.engine)
        self.session = DBSession()

    def commit(self):
        self.session.commit()

    def close(self):
        self.session.close()

    def rollback(self):
        self.session.rollback()

    def data_base_init(self):
        # Base.metadata.drop_all(self.engine)
        Base.metadata.create_all(self.engine)

    def data_base_add(self):
        Base.metadata.create_all(self.engine)


class UserSearchKeyWordHistory(Base):
    '''
    用户搜索历史数据表
    '''
    __tablename__ = 'tb_searchword_history'
    index = Column(Integer(), primary_key=True, index=True)
    uid = Column(Integer(), nullable=True)
    vin = Column(String(255), nullable=False)
    time = Column(DateTime, nullable=False)
    keyword = Column(String(255), nullable=False)
    showinlist = Column(Boolean, nullable=False)


class UserTracksHistoryList(Base):
    '''
    单曲历史列表
    '''
    __tablename__ = 'tb_tracks_history'
    index = Column(Integer(), primary_key=True, index=True)
    uid = Column(Integer(), nullable=True)
    vin = Column(String(255), nullable=False)
    time = Column(DateTime, nullable=False)
    track_id = Column(Integer(), nullable=False)
    track_title = Column(String(255), nullable=True)
    announcer_id = Column(Integer(), nullable=True)
    nickname = Column(String(255), nullable=True)
    category_id = Column(Integer(), nullable=True)
    album_id = Column(Integer(), nullable=True)
    album_title = Column(String(255), nullable=True)
    play_count = Column(Integer(), nullable=True)
    modifiedtime = Column(DateTime, nullable=False)
    valid = Column(Boolean, nullable=False)
    cover_url_small = Column(String(1024), nullable=True)
    cover_url_middle = Column(String(1024), nullable=True)
    cover_url_large = Column(String(1024), nullable=True)
    duration = Column(String(255), nullable=False)
    play_url_32 = Column(String(1024), nullable=True)
    play_url_64 = Column(String(1024), nullable=True)
    duration = Column(Integer(), nullable=True)


class Track(Base):
    '''
    单曲信息
    '''
    __tablename__ = 'tb_track'
    track_id = Column(Integer(), primary_key=True, nullable=False)
    track_title = Column(String(255), nullable=True)

    announcer_id = Column(Integer(), nullable=True)
    nickname = Column(String(255), nullable=True)
    category_id = Column(Integer(), nullable=True)

    album_id = Column(Integer(), nullable=True)
    album_title = Column(String(255), nullable=True)

    play_count = Column(Integer(), nullable=True)
    comment_count = Column(Integer(), nullable=True)

    imageSmall = Column(String(1024), nullable=True)
    imageLarge = Column(String(1024), nullable=True)
    imageMiddle = Column(String(1024), nullable=True)

    duration = Column(Integer(), nullable=True)


class UserCollectTrack(Base):
    '''
    收藏单曲
    '''
    __tablename__ = 'tb_user_collect_track'
    index = Column(Integer(), primary_key=True, index=True)
    uid = Column(Integer(), nullable=True)
    vin = Column(String(255), nullable=False)
    track_id = Column(Integer(), nullable=False)
    track_title = Column(String(255), nullable=True)
    cover_url_small = Column(String(1024), nullable=True)
    cover_url_middle = Column(String(1024), nullable=True)
    cover_url_large = Column(String(1024), nullable=True)
    duration = Column(String(255), nullable=False)
    play_url_32 = Column(String(1024), nullable=True)
    play_url_64 = Column(String(1024), nullable=True)
    favorite = Column(Boolean, nullable=False)
    time = Column(DateTime, nullable=False)


class UserCollectPlayList(Base):
    '''
    收藏歌单
    '''
    __tablename__ = 'tb_user_collect_playlist'
    index = Column(Integer(), primary_key=True, index=True)
    uid = Column(Integer(), nullable=True)
    vin = Column(String(255), nullable=False)
    playlistid = Column(Integer(), nullable=False)
    playlistname = Column(String(255), nullable=True)
    imageSmall = Column(String(1024), nullable=True)
    imageMiddle = Column(String(1024), nullable=True)
    imageLarge = Column(String(1024), nullable=True)
    favorite = Column(Boolean, nullable=False)
    time = Column(DateTime, nullable=False)
    selflist = Column(Boolean, nullable=False)  ##是否为自建歌单


class UserPlayList(Base):
    '''
    用户歌单
    '''
    __tablename__ = 'tb_user_playlist'
    playlistid = Column(Integer(), primary_key=True, index=True)
    playlistname = Column(String(255), nullable=True)
    uid = Column(Integer(), nullable=True)
    vin = Column(String(255), nullable=False)
    favorite = Column(Boolean, nullable=False)
    imageSmall = Column(String(1024), nullable=True)
    imageMiddle = Column(String(1024), nullable=True)
    imageLarge = Column(String(1024), nullable=True)
    createtime = Column(DateTime, nullable=False)
    modifiedtime = Column(DateTime, nullable=False)


class UserPlayListContent(Base):
    '''
    用户歌单内容
    '''
    __tablename__ = 'tb_user_playlist_content'
    index = Column(Integer(), primary_key=True, index=True)
    playlistid = Column(Integer(), nullable=False)
    track_id = Column(Integer(), nullable=False)
    track_title = Column(String(255), nullable=True)
    valid = Column(Boolean, nullable=False)
    time = Column(DateTime, nullable=False)


class UserCollectAlbum(Base):
    """
    collect album
    """
    __tablename__= 'tb_user_collect_album'
    index = Column(Integer(), primary_key=True, index=True)
    uid = Column(Integer(), nullable=True)
    vin = Column(String(255), nullable=False)
    album_id = Column(Integer(), nullable=False)
    album_title = Column(String(255), nullable=True)
    cover_url_small = Column(String(1024), nullable=True)
    cover_url_middle = Column(String(1024), nullable=True)
    cover_url_large = Column(String(1024), nullable=True)
    favorite = Column(Boolean, nullable=False)
    time = Column(DateTime, nullable=False)
    selflist = Column(Boolean, nullable=False)


class UserCollectRadio(Base):
    """
    collect radio
    """
    __tablename__= 'tb_user_collect_radio'
    index = Column(Integer(), primary_key=True, index=True)
    uid = Column(Integer(), nullable=True)
    vin = Column(String(255), nullable=False)
    id = Column(Integer(), nullable=False)
    radio_name = Column(String(255), nullable=True)
    cover_url_small = Column(String(1024), nullable=True)
    cover_url_large = Column(String(1024), nullable=True)
    favorite = Column(Boolean, nullable=False)
    time = Column(DateTime, nullable=False)
    selflist = Column(Boolean, nullable=False)


class UserCollectAnnouncer(Base):
    """
    collect announcer
    """
    __tablename__= 'tb_user_collect_announcer'
    index = Column(Integer(), primary_key=True, index=True)
    uid = Column(Integer(), nullable=True)
    vin = Column(String(255), nullable=False)
    id = Column(Integer(), nullable=False)
    nickname = Column(String(255), nullable=True)
    avatar_url = Column(String(1024), nullable=True)
    favorite = Column(Boolean, nullable=False)
    time = Column(DateTime, nullable=False)
    selflist = Column(Boolean, nullable=False)


class UserTrackRecord(Base):
    """
    record last play position
    """
    __tablename__ = 'tb_track_record'
    index = Column(Integer(), primary_key=True, index=True)
    uid = Column(Integer(), nullable=True)
    vin = Column(String(255), nullable=False)
    album_id = Column(Integer(), nullable=True)
    track_id = Column(Integer(), nullable=True)
    position = Column(Integer(), nullable=False)
    time = Column(DateTime, nullable=False)


def gen_keywords(Conn):
    # query = Conn.session.query(UserSearchKeyWordHistory)
    init = 1483200000.0
    uid = [888888, None, 666666]
    vin_code = ['LSJA01234567890112', 'LSJA01234567890118', 'LSJA02234567890112']
    keywords = ['流金岁月', '经典老歌', '影视金曲', '内地流行', '港台流行', '日韩流行', '欧美金曲', '摇滚', '少儿歌曲', '热门对唱', '校园民谣', '网络歌曲', '轻音乐',
                '天籁之声', '劲爆']
    for i in range(20):
        timestamp = init + 86400 * random.randint(0, 300) + random.randint(0,23)*60*60 + random.randint(0,60)
        timeArray = datetime.datetime.fromtimestamp(timestamp)
        user_index = random.randint(0,2)
        keywords_index = random.randint(0,len(keywords)-1)

        data = {'uid':uid[user_index], 'vin':vin_code[user_index], 'time':timeArray, 'keyword':keywords[keywords_index],
                'showinlist':True}
        add_item = UserSearchKeyWordHistory(**data)
        Conn.session.add(add_item)
    Conn.commit()
    Conn.close()


def gen_tracks(Conn):
    tracks = []
    for i in range(18):
        s = {'rank_key': '1_57_ranking:track:scoreByTime:1:0',
             'page': '%s'%(i+1),
             'count': '100'}
        b = ranks_api.RanksTracks(s).get()['tracks']
        tracks += b
    for i in tracks:
        print(i)
        track_id = i['id']
        query = Conn.session.query(Track).filter_by(track_id=track_id).all()
        print(query)
        if query == []:
            track_title = i['track_title']
            announcer_id = i['announcer']['id']
            nickname = i['announcer']['nickname']
            album_id = i['subordinated_album']['id']
            album_title = i['subordinated_album']['album_title']
            play_count = i['play_count']
            comment_count = i['comment_count']
            imageSmall = i['cover_url_small']
            imageMiddle = i['cover_url_middle']
            imageLarge = i['cover_url_large']
            duration = i['duration']
            data = {'track_id': track_id,
                    'track_title': track_title,
                    'announcer_id': announcer_id,
                    'nickname': nickname,
                    'album_id': album_id,
                    'album_title': album_title,
                    'play_count': play_count,
                    'comment_count': comment_count,
                    'imageSmall': imageSmall,
                    'imageMiddle': imageMiddle,
                    'imageLarge': imageLarge,
                    'duration': duration}
            print(data)
            add_item = Track(**data)
            Conn.session.add(add_item)
    Conn.commit()
    Conn.close()


def gen_trackhistory(Conn):
    query = Conn.session.query(Track)
    u = query.all()
    l = len(u)
    init = 1483200000.0
    uid = [123456, None, 666666]
    vin_code = ['LSJA01234567890112', 'LSJA01234567890118', 'LSJA02234567890112']
    for i in range(900):
        timestamp = init + 86400 * random.randint(0, 300) + random.randint(0, 23) * 60 * 60 + random.randint(0, 60)
        timeArray = datetime.datetime.fromtimestamp(timestamp)
        user_index = random.randint(0, 2)
        track_index = random.randint(0, l-1)
        track = u[track_index]
        data = {'uid': uid[user_index],
                'vin': vin_code[user_index],
                'time': timeArray,
                'track_id': track.track_id,
                'track_title': track.track_title,
                'announcer_id': track.announcer_id,
                'nickname': track.nickname,
                'album_id': track.album_id,
                'album_title': track.album_title,
                'play_count': track.play_count,
                'modifiedtime': timeArray,
                'valid': True}
        add_item = UserTracksHistoryList(**data)
        Conn.session.add(add_item)
    Conn.commit()
    Conn.close()



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
# @Time    : 17-12-22 下午2:32
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : cache
# @Contact : guangze.yu@foxmail.com
"""

import database.data_base as db
import redis
import json
import traceback
import datetime

pool = redis.ConnectionPool(host='127.0.0.1', password='Root1q2w', port=6379)
cache = redis.Redis(connection_pool=pool)


class Common(object):
    def __init__(self, vin, uid=None, Conn=cache):
        self._vin = vin
        self._uid = uid
        self._conn = Conn


class SearchWordHistory(Common):
    def __init__(self, vin, uid=None, Conn=cache):
        super(SearchWordHistory, self).__init__(vin, uid, Conn)

    def get(self):
        try:
            if self._uid is None:
                out = cache.hget(self._uid,'VoiceSearchWordHistory')
            else:
                out = cache.hget(self._vin,'VoiceSearchWordHistory')
            if out is None:
                dbout = db.SearchWordHistory(self._vin, self._uid)
                if dbout is None:
                    dbout = []
                cache.hset(self._uid, 'VoiceSearchWordHistory',json.dumps(dbout))
                info = dbout
            else:
                info = json.loads(out)
            return info
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def clear(self):
        try:
            if self._uid is None:
                info = cache.hget(self._vin, 'VoiceSearchWordHistory')
            else:
                info = cache.hget(self._uid, 'VoiceSearchWordHistory')
            if info is None or info == []:
                return True
            else:
                cache.hset(self._uid,'VoiceSearchWordHistory',json.dumps([]))
                db.SearchWordHistory(self._vin,self._uid).clear()
                return True
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def add(self, timestamp, keyword):
        try:
            db.SearchWordHistory(self._vin,self._uid).add(timestamp,keyword)
            if self._uid is None:
                uid = self._vin
            else:
                uid = self._uid
            cacheinfo = cache.hget(uid,'VoiceSearchWordHistory')
            if cacheinfo is None:
                cache.hset(uid, 'VoiceSearchWordHistory', json.dumps([{'keyword':keyword}]))
                return True
            else:
                info = json.loads(cacheinfo)
                keywords = [i['keyword'] for i in info]
                try:
                    index = keywords.index(keyword)
                    info.__delitem__(index)
                    info.append({'keyword':keyword})
                    cache.hset(uid,'VoiceSearchWordHistory',json.dumps(info))
                except:
                    info.append({'keyword': keyword})
                    cache.hset(uid,'VoiceSearchWordHistory',json.dumps(info))
                return True
        except:
            traceback.print_exc()
            print('cache failre')
            return False


class TracksHistoryList(Common):
    def __init__(self, vin, uid=None, Conn=cache):
        super(TracksHistoryList, self).__init__(vin, uid, Conn)

    def get(self, starttime=datetime.datetime.now()-datetime.timedelta(180), endtime=datetime.datetime.now()):
        try:
            if self._uid is None:
                uid = self._vin
            else:
                uid = self._uid
            out = cache.hget(uid,'TracksHistoryList')
            if out is None:
                dbout = db.TracksHistoryList(self._vin,self._uid).get(starttime, endtime)
                if dbout is None or dbout==[]:
                    dbout = []
                info = dbout
                cache.hset(uid,'TracksHistoryList',json.dumps(dbout))
                return info
            else:
                info = json.loads(out)
                return info
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def add(self, timestamp, itemid):
        try:
            if self._uid is None:
                uid = self._vin
            else:
                uid = self._uid
            db.TracksHistoryList(self._vin,self._uid).add(timestamp,itemid)
            info = db.TracksHistoryList(self._vin,self._uid).get()
            cache.hset(uid,'TracksgHistoryList',json.dumps(info))
            statinfo = db.TracksHistoryList(self._vin,self._uid).stat()
            cache.hset(uid, 'TracksHistoryListStat', json.dumps(statinfo))
            return True
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def stat(self, n=50, starttime=datetime.datetime.now()-datetime.timedelta(180), endtime=datetime.datetime.now()):
        try:
            if self._uid is None:
                uid = self._vin
            else:
                uid = self._uid
            out = cache.hget(uid,'TracksHistoryListStat')
            if out is None:
                info = db.TracksHistoryList(self._vin,self._uid).stat(n,starttime,endtime)
                cache.hset(uid,'TracksHistoryListStat',json.dumps(info))
                return info
            else:
                return json.loads(out)
        except:
            traceback.print_exc()
            print('cache failre')
            return False


class CollectSong(Common):
    def __init__(self, vin, uid=None, Conn=cache):
        super(CollectSong, self).__init__(vin, uid, Conn)

    def get(self):
        try:
            if self._uid is None:
                uid = self._vin
            else:
                uid = self._uid
            out = cache.hget(uid,'CollectTrack')
            if out is None:
                dbout = db.CollectTrack(self._vin,self._uid).get()
                cache.hset(uid,'CollectTrack',json.dumps(dbout))
                return dbout
            else:
                return json.loads(out)
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def add(self, timestamp, itemid):
        try:
            db.CollectTrack(self._vin,self._uid).add(timestamp,itemid)
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def cancel(self, timestamp, itemid):
        try:
            db.CollectTrack(self._vin,self._uid).cancel(timestamp,itemid)
        except:
            traceback.print_exc()
            print('cache failre')
            return False


class CollectPlayList(Common):
    def __init__(self, vin, uid=None, Conn=cache):
        super(CollectPlayList, self).__init__(vin, uid, Conn)

    def get(self):
        try:
            if self._uid is None:
                uid = self._vin
            else:
                uid = self._uid
            out = cache.hget(uid,'VoiceCollectPlayList')
            if out is None:
                dbout = db.CollectPlayList(self._vin,self._uid).get()
                cache.hset(uid,'VoiceCollectPlayList',json.dumps(dbout))
                return dbout
            else:
                return json.loads(out)
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def add(self, timestamp, playlistid, selflist=False):
        try:
            db.CollectPlayList(self._vin,self._uid).add(timestamp,playlistid,selflist)
            return True
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def cancel(self,timestamp, playlistid, selflist=False):
        try:
            db.CollectPlayList(self._vin,self._uid).cancel(timestamp,playlistid,selflist)
            return True
        except:
            traceback.print_exc()
            print('cache failre')
            return False


class CollectAlbum(Common):
    def __init__(self, vin, uid=None, Conn=cache):
        super(CollectAlbum, self).__init__(vin, uid, Conn)

    def get(self):
        try:
            if self._uid is None:
                uid = self._vin
            else:
                uid = self._uid
            out = cache.hget(uid,'VoiceCollectAlbum')
            if out is None:
                dbout = db.CollectAlbum(self._vin,self._uid).get()
                cache.hset(uid,'VoiceCollectAlbum',json.dumps(dbout))
                return dbout
            else:
                return json.loads(out)
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def add(self, timestamp, album_id, selflist=False):
        try:
            db.CollectAlbum(self._vin,self._uid).add(timestamp,album_id,selflist)
            return True
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def cancel(self,timestamp, album_id, selflist=False):
        try:
            db.CollectAlbum(self._vin,self._uid).cancel(timestamp,album_id,selflist)
            return True
        except:
            traceback.print_exc()
            print('cache failre')
            return False


class CollectRadio(Common):
    def __init__(self, vin, uid=None, Conn=cache):
        super(CollectRadio, self).__init__(vin, uid, Conn)

    def get(self):
        try:
            if self._uid is None:
                uid = self._vin
            else:
                uid = self._uid
            out = cache.hget(uid,'VoiceCollectRadio')
            if out is None:
                dbout = db.CollectAlbum(self._vin,self._uid).get()
                cache.hset(uid,'VoiceCollectRadio',json.dumps(dbout))
                return dbout
            else:
                return json.loads(out)
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def add(self, timestamp, id, selflist=False):
        try:
            db.CollectRadio(self._vin,self._uid).add(timestamp,id,selflist)
            return True
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def cancel(self,timestamp, id, selflist=False):
        try:
            db.CollectRadio(self._vin,self._uid).cancel(timestamp,id,selflist)
            return True
        except:
            traceback.print_exc()
            print('cache failre')
            return False


class UserPlaylist(Common):
    def __init__(self, vin, uid=None, Conn=cache):
        super(UserPlaylist, self).__init__(vin, uid, Conn)

    def get(self):
        try:
            if self._uid is None:
                uid = self._vin
            else:
                uid = self._uid
            out = cache.hget(uid,'VoiceUserPlaylist')
            if out is None:
                dbout = db.UserPlaylist(self._vin,self._uid).get()
                cache.hset(uid,'VoiceUserPlaylist',json.dumps(dbout))
                return dbout
            else:
                return json.loads(out)
        except:
            traceback.print_exc()
            return False

    def create(self,playlistname):
        try:
            db.UserPlaylist(self._vin,self._uid).create(playlistname)
            return True
        except:
            traceback.print_exc()
            return False

    def add(self, timestamp, playlistid, itemid):
        try:
            db.UserPlaylist(self._vin, self._uid).add(timestamp,playlistid,itemid)
            return True
        except:
            traceback.print_exc()
            print('add failre')
            return False

    def cancel(self, timestamp, playlistid, itemid):
        try:
            db.UserPlaylist(self._vin,self._uid).cancel(timestamp, playlistid, itemid)
            return True
        except:
            traceback.print_exc()
            print('cancel failre')
            return False

    def getplaylistcontent(self, playlistid):
        try:
            if self._uid is None:
                uid = self._vin
            else:
                uid = self._uid
            out = cache.hget(uid,'VoiceUserPlaylistContent')
            if out is None:
                dbout = db.UserPlaylist(self._vin,self._uid).getplaylistcontent(playlistid)
                cache.hset(uid,'VoiceUserPlaylistContent',json.dumps(dbout))
                return dbout
            else:
                return json.loads(out)
        except:
            traceback.print_exc()
            print('getplaylistcontent failre')
            return False


class CollectAnnouncer(Common):
    def __init__(self, vin, uid=None, Conn=cache):
        super(CollectAnnouncer, self).__init__(vin, uid, Conn)

    def get(self):
        try:
            if self._uid is None:
                uid = self._vin
            else:
                uid = self._uid
            out = cache.hget(uid,'VoiceCollectAnnouncer')
            if out is None:
                dbout = db.CollectAnnouncer(self._vin,self._uid).get()
                cache.hset(uid,'VoiceCollectAnnouncer',json.dumps(dbout))
                return dbout
            else:
                return json.loads(out)
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def add(self, timestamp, id, selflist=False):
        try:
            db.CollectAnnouncer(self._vin,self._uid).add(timestamp,id,selflist)
            return True
        except:
            traceback.print_exc()
            print('cache failre')
            return False

    def cancel(self,timestamp, id, selflist=False):
        try:
            db.CollectAnnouncer(self._vin,self._uid).cancel(timestamp,id,selflist)
            return True
        except:
            traceback.print_exc()
            print('cache failre')
            return False



#!/usr/bin/python3
# -*- coding: utf-8 -*-
"""
# @Time    : 2018/3/7 15:02
# @Author  : guangze.yu
# @Site    : shanghai
# @File    : decorator
# @Project : roewe_voice 
# @Contact : guangze.yu@foxmail.com
"""

import time
import utils.result as result
import utils.exception as exception


def params_check(func):
    def wrapper(params):
        if 'vin' not in params:
            return result.ErrorResult(exception.NoVinError())
        if 'timestamp' not in params:
            return result.ErrorResult(exception.NoTimeStampError())
        params['timestamp'] = time.time()
        if 'uid' not in params:
            params['uid'] = None
        return func(params)
    return wrapper
